﻿/*																	*
 * This file is a part of an example of how to communicate			*
 * with IceWarp Unified Messaging server using COM interface calls	*
 *																	*
 * This program is distributed in the hope that it will be useful,	*
 * but WITHOUT ANY WARRANTY; without even the implied warranty of	*
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.				*
 *																	*
 * IceWarp Ltd 2011													*
 *																	*/

using System;
using System.Collections.Generic;
using System.Runtime.InteropServices;
using System.Linq;
using System.Text;
using api;

namespace ApiCallExample
{
	class Program
	{
		private static IAccountObject m_accountComInterface;
		private static object m_accountObj;
		private static Type m_associatedType;

		private static IAccountObject AccountComInterface
		{
			get
			{
				if (m_accountComInterface == null)
				{
					m_accountComInterface = m_accountObj as IAccountObject;
				}

				return m_accountComInterface;
			}
		}

		static void Main(string[] args)
		{
			// Ask for associated type
			if ((m_associatedType = Type.GetTypeFromProgID("IceWarpServer.AccountObject")) != null)
			{
				try
				{
					m_accountObj = Activator.CreateInstance(m_associatedType);
					if (AccountComInterface != null)
					{						
						string account = "username@domain.com";
						bool newAccountSuccess = true;

						if (!(newAccountSuccess &= AccountComInterface.Open(account)))
						{																		
							Console.WriteLine("Unable to open the account, creating one");							

							newAccountSuccess &= AccountComInterface.New(account);
							newAccountSuccess &= AccountComInterface.Save();
							newAccountSuccess &= AccountComInterface.Open(account);
						}

						if (newAccountSuccess)
						{
							AccountComInterface.SetProperty("u_comment", "SomeComment");
							AccountComInterface.Save();
						}
						else
						{
							Console.WriteLine("Unable to open or create new account");
						}
					}
					else
					{
						Console.WriteLine("Unable to create COM interface, or returned COM is not of appropriate type");
					}
				}
				catch (Exception ex)
				{
					Console.WriteLine(String.Format("Unable to create COM because: {0}", ex.Message));
				}
			}
		}
	}
}