//////////////////////////////////////////////////////////////////////////////////////////////
// This file contains all API variables. The variables are grouped according to the GUI.   //
// These variables can be used either with the tool.exe command line tool or directly       //
// for API  programming.								    //
//											    //
// Syntax:										    //
//											    //
// Variable name	Variable type		Description		Default value 	    //
//                                                                                          //
// Description control codes                                                                //
// [R] - Read only value                                                                    //
// [D] - Display only value
//			     								    //
//////////////////////////////////////////////////////////////////////////////////////////////

Unit apiconst;

Interface

Const
// Function Result Codes
  S_OK = $00;

  E_FAILURE = -$01; // Function failure
  E_LICENSE = -$02; // Insufficient license
  E_PARAMS = -$03; // Size of parameters too short
  E_PATH = -$04; // Settings file does not exist
  E_CONFIG = -$05; // Configuration not found
  E_PASSWORD = -$06; // Password policy
  E_CONFLICT = -$07; // Item already exists
  E_INVALID = -$08; // Invalid mailbox / alias characters
  E_PASSWORDCHARS = -$09; // Invalid password characters

/////////////
// Domains //
/////////////

	// Domain
	D_Description = $00; 			// String		Domain description
	D_Type = $01;				// Int			Domain Type
		// 0 -  Standard domain
		// 1 - ETRN/ATRN queue
		// 2 - Domain Alias
		// 3 - Backup domain
		// 4 - Distributed domain
	D_DomainValue = $03; 			// String		Domain Type To value
	D_VerifyType = $21;          		// Int			User verification mode
		// 0 - Default
		// 1 - Issue RCPT
		// 2 - Issue VRFY
                // 3 - Minger
	D_MingerPassword = $362; 		// String		Minger Password for this domain
	D_PostMaster = $04; 			// String		Default Administrator's alias
 	D_AdminEmail = $05;			// String		Administrator's email		
  	D_UnknownUsersType = $06;	 	// Int			Unknown users action
		// 0 - Reject
		// 1 - Forward to address
		// 2 - Delete
	D_UnknownForwardTo = $07;		// String		Unknown users Forward to Address
 	D_InfoToAdmin = $08;			// Bool			Send information to administrator

	// Options
	D_AccountNumber = $09;			// Int			Domain Admin account limit
	D_DiskQuota = $0B;			// Int			Domain disk quota (kB)
	D_DisableLogin = $10;			// Bool			Disable login to this domain
	D_UserMailbox = $0C;			// Int			User Mailbox size (kB)
	D_UserMB = $0D;				// Int			User send out data limit (MB/day)
	D_UserNumber = $0E;			// Int			User send out messages limit (#/day)
	D_UserMsg = $0F;			// Int			User max message size (kb)
	D_Expires = $15;              		// Bool			Enable domain expiration
 	D_ExpiresOn = $16;		        // Int			Domain Expires On (Number of days from 1899/12/30)
        D_ExpiresOn_Date = $292;	        // String	        Domain Expires On (Date in yyyy/mm/dd format)
	D_NotifyExpire = $17;         		// Bool			Enable Notify before expiration
	D_NotifyBeforeExpires = $18;  		// Int			Notify before expiration (Days)
  	D_DeleteExpired = $19;       		// Bool			Delete Expired domains
        D_NumberLimit = $27;                    // Int			Limit of emails sent from domain per day
        D_VolumeLimit = $28;                    // Int			Limit of data sent from domain per day
        D_ASSupport = $283;                     // Bool			Domain has AV support [R]
        D_QuarantineSupport = $284;             // Bool			Domain has Quarantine support [R]
        D_AVSupport = $44A;                     // Bool			Domain has AV support [R]
        D_IMSupport = $44B;                     // Bool			Domain has IM support [R]
        D_SIPSupport = $44C;                     // Bool			Domain has SIP support [R]
        D_FTPSupport = $44D;                     // Bool			Domain has FTP support [R]
        D_SMSSupport = $44E;                     // Bool			Domain has SMS support [R]
        D_GWSupport = $44F;                     // Bool			Domain has GW support [R]
        D_WebDAVSupport = $450;                     // Bool			Domain has WebDAV support [R]
        D_EASSupport = $451;                     // Bool			Domain has ActiveSync support [R]
        D_SyncMLSupport = $452;                     // Bool			Domain has SyncML support [R]
        D_ConnectorSupport = $453;                     // Bool			Domain has Connector support [R]
        D_DesktopSupport = $454;                     // Bool			Domain has DC support [R]
        D_ArchiveSupport = $455;                     // Bool			Domain has Archive support [R]

	D_HeaderFile = $33A;           	        // String		Header file
	D_HeaderHTMLFile = $33B;           	// String		Header HTML file
      	D_FooterFile = $33C;           	        // String		Footer file
	D_FooterHTMLFile = $33D;       	        // String		Footer HTML fila
        D_HeaderFooterFlag = $33E;              // Integer              Bit Mask
                // HF_L2L = $01;
                // HF_L2R = $02;
                // HF_R2L = $04;
                // HF_R2R = $08;


	//Miscellaneous
	D_Hostname = $23;             		// String               Hostname
        D_IPAddress = $25;                      // String
	D_Folderpath = $24;            		// String               Folder path
  D_BaseMailboxPath = $459;         // String     Full path to root of the domain storage, read only, equals to C_System_Storage_Dir_MailPath/Domain name
	D_AVScan = $0A;				// Bool			Policy - AV
	D_AntiSpam = $11;			// Bool			Policy - Antispam
	D_ChallengeResponse = $14;    		// Bool			Policy - Challenge Response
	D_IM = $13;		                // Bool			Policy - IM
	D_Calendar = $12; 		        // Bool			Policy - GW
  	D_SIP = $22; 		                // Bool			Policy - SIP
        D_SyncML = $29;                         // Bool                 Policy - SyncML
        D_FTP = $2A;                            // Bool                 Policy - FTP
        D_SMS = $2B;                            // Bool                 Policy - SMS
        D_ActiveSync = $2C;                     // Bool                 Policy - ActiveSync
        D_WebDAV = $2D;                         // Bool                 Policy - WebDAV
        D_Archive = $466;               // Bool                 Policy - Archive
        D_Client_Connector = $31B;              // Bool
        D_Client_Desktop = $31C;                // Bool

        D_Backup = $20;                         // String               Structure backup [D]

        D_SMSContent = $432;       // String  SMS file content [R]

        D_RulesContentXML = $26;                // String [D]
        D_SharedRoster = $336;                  // Bool

        D_SMS_SentLastMonth =$360;              // Int                  Number of SMS sent last month, only valid if Policy for SMS is "use domain options" [R]
        D_SMS_SentThisMonth =$361;              // Int                  Number of SMS sent this month, only valid if Policy for SMS is "use domain options" [R]

//////////////
// Accounts //
//////////////

Const
	// Accounts shared
	U_Type = $00;				// Int			Account type [A]
        	// 0 - User
		// 1 - Mailing list
		// 2 - Executable
		// 3 - Notification
		// 4 - Static Route
		// 5 - Catalog
		// 6 - List server
		// 7 - Group
                // 8 - Resource

        U_Alias = $03;                         // String	        Account's alias [A]
        U_AliasList = $487;                    // String   Read only list of all account e-mails (i.e. uses also knowledge about domain aliases)
        U_Name = $02;                          // String		Account's full name/description [A]
        U_Backup = $06;                        // String                Structure backup [D][A]
        
        U_GW_DailyAgenda = $447;                // Bool			[A]
        U_GW_Reminders = $448;                  // Bool			[A]

	// Accounts

		// User
                U_EmailAlias = $4F;             // String               Email alias
                U_PhoneAlias = $55;             // String               Phone alias

		U_Mailbox = $10;                // String		Username
		U_Password = $21;               // String		Password
		U_AuthMode   = $18;             // Int			Authentication mode
			// 0 - Standard
			// 1 - NT domain
			// 2 - Active Directory
			// 3 - Any password
                U_Login =$430;                  // String               Read only - string which should be used for logging into API, respects c_accounts_policies_login_loginsettings
		U_AuthModeValue = $22;          // String		Authentication mode value
  		U_Comment = $05;              	// String		User comment
		U_AccountType = $19;            // Int			Mailbox protocol type
			// 0 - POP3
			// 1 - IMAP & POP3
			// 2 - IMAP

		U_Admin = $26;                	// Bool			Administrator permission
		U_DomainAdmin = $24;            // Bool			Domain admin permission
		U_GatewayAdmin = $342;          // Bool			Gateway admin permission
		U_AccountDisabled = $11;        // Int			Account state
			// 0 - Enabled
			// 1 - Disabled (Login)
			// 2 - Disabled (Login, Receive)
			// 3 - Disabled (Tarpitting)
		U_ForwardTo = $2D;              // String		Forward to address

		// Mailbox
		U_UseRemoteAddress = $2C;       // Bool			Mailbox local/remote
			// 0 - Local mailbox
			// 1 - Remote address
		U_MailBoxPath = $25;            // String		Mailbox path
                U_FullMailboxPath = $1C;        // String               Full mailbox path [R]
		U_RemoteAddress = $37;          // String		Remote address
		U_MaxBox = $27;                 // Bool			Enable mailbox size limit
		U_MaxBoxSize = $28;             // Int			Mailbox size limit (kB)
		U_MegabyteSendLimit = $39;      // Int			Send out data limit (MB/day)
		U_NumberSendLimit = $3A;        // Int			Send out messages limit (#/day)
                U_InboxCountLimit = $42C;        // Int                  Maximum allowed number of items in inbox
 		U_MaxMessageSize = $1B;         // Int			User max message size (kB)
		U_DeleteOlder = $32;            // Bool			Enable Delete messages older than
		U_DeleteOlderDays = $33;        // Int			Delete messages older than (Days)
		U_ForwardOlder = $34;           // Bool			Enable Forward messages older than
		U_ForwardOlderDays = $35;       // Int			Forward messages older than (Days)
		U_ForwardOlderTo = $36;         // String		Forward messages older than x to address
		U_MailIn = $2F;                 // String		Copy incoming email address
        U_MailInUseCF = $307;           // Bool		        Apply CF on incoming mail being copied
		U_MailOut = $30;                // String		Copy outgoing email address
        U_MailOutUseCF = $308;          // Bool		        Apply CF on outgoing mail being copied
		U_AlternateEmail = $4D;         // String		Alternate email

		// Options
		U_NULL = $20;                   // Bool			Null account
		U_ETRN = $1E;                   // Bool			ETRN/ATRN account
		U_XEnvelopeTo = $3C;            // Bool			Add X-Envelope-To header to all messages
		U_NoMailList = $3B;    	        // Bool			No mailing lists
		U_LocalDomain = $2B;            // Bool			User can send to local domains only
		U_InactiveFor = $41;            // Int			Expires if inactive for (Days)
		U_AccountValid = $12;           // Bool			Enable Expires on
		U_AccountValidTill = $13;       // Int			Expires on (Number of days from 1899/12/30)
		U_AccountValidTill_Date = $293; // String		Expires on (Date in yyyy/mm/dd format)
		U_ValidityReport = $16;         // Bool			Enable Notify before exiration
		U_ValidityReportDays = $17;     // Int			Notify before expiration (Days)
  		U_DeleteExpire = $1F;         	// Bool			Delete account when expired
		U_ValidReport = $31;            // String		Notification file

		// Miscellaneous
		U_SpamFolder = $40;             // Int			Spam folder mode
			// 0 - Default
			// 1 - Do not use Spam folder
			// 2 - Use Spam folder
  		U_QuarantineReports = $43;      //Int
		      	// 0 - Disabled
			// 1 - Default
			// 2 - New Items only
			// 3 - All items
		U_SpamAdmin = $3F;              // Bool			Spam administrator
 		U_SMTP = $45;       	        // Bool			Policy - SMTP
		U_POP3IMAP = $46;    	        // Bool			Policy - IMAP & POP3
		U_WebMail = $47;     	        // Bool			Policy - Webmail
		U_AVScan = $04;                 // Bool			Policy - AV
		U_AS = $48;          		// Bool			Policy - AntiSpam
  		U_CR = $49;          		// Bool			Obsolete
  		U_Quarantine = $49;   		// Bool			Policy - Challenge response
  		U_IM = $4A;          		// Bool			Policy - IM
  		U_GW = $4B;          		// Bool			Policy - Groupware
		U_SIP = $4E;          		// Bool			Policy - SIP
                U_SyncML = $56;                 // Bool                 Policy - SyncML
                U_FTP = $224;                   // Bool                 Policy - FTP
                U_SMS = $225;                   // Bool                 Policy - SMS
                U_ActiveSync = $226;            // Bool                 Policy - ActiveSync
                U_WebDAV = $227;                // Bool                 Policy - WebDav
                U_Archive = $465;               // Bool                 Policy - Archive

    U_SIP_ONLINE = $45D;                         // Bool                 User is logged into local VOIP service , read only
    U_SIP_AVAILABLE = $45E;                      // Bool                 User is logged into local VOIP service and is not calling now , read only

    U_IM_ONLINE = $463;                          // Bool                 User is logged into local IM service , read only
    U_IM_ROSTER_CONTENTS =$488;                  // String               Raw contents of user roster file

    U_GROUPS =  $46D;                            // String               List of groups where user is member of, read only, computed online
    U_GROUPSLIST =  $494;                        // String               List of groups where user is member of, including all combinations of aliases/domain aliases, read only, computed online

		// Responder
		U_Respond = $2A;              	// Int			Autoresponder mode
			// 0 - Do not respond
			// 1 - Respond always
			// 2 - Respond once
			// 3 - Respond once in period
	  	U_RespondPeriod = $42;        	// Int			Responder period (Days)
  		U_RespondWith = $2E;          	// String		Responder file
		U_ReplyFrom = $3D;            	// String		Reply from
  		U_RespondBetweenFrom = $44;     // String		Responder active from (Date)
  		U_RespondBetweenTo = $4C;       // String		Responder active till (Date)
  		U_RespondOnlyIfToMe = $3E;    	// Bool			Reply only if to me
                U_ResponderContent = $E0;       // String               Auto responder content
                U_NoRespondFor = $321;          // String

                U_QuarantineSupport = $E1;      // Bool                 Read only variable to check if the user has quarantine enabled [R]
                U_ASSupport = $E2;              // Bool                 Read only variable to check if the user has antispam enabled [R]
                U_SpamFolderSupport = $E3;      // Bool                 Read only variable to check if the user has spam folder enabled [R]
                U_SIPSupport = $105;            // Bool                 Read only variable to check if the user has SIP enabled [R]
                U_AVSupport = $220;             // Bool                 Read only variable to check if the user has antivirus enabled [R]
                U_IMSupport = $221;             // Bool                 Read only variable to check if the user has instant messaging enabled [R]
                U_GWSupport = $222;             // Bool                 Read only variable to check if the user has groupware enabled [R]
                U_SharingAvailable = $349;      // Bool                 Read only variable to check if the user can use sharing [R]

                U_SyncMLSupport = $223;         // Bool                 Read only variable to check if the user has syncML enabled [R]
                U_FTPSupport = $228;         // Bool                 Read only variable to check if the user has FTP enabled [R]
                U_SMSSupport = $229;         // Bool                 Read only variable to check if the user has SMS enabled [R]
                U_ActiveSyncSupport = $22A;         // Bool                 Read only variable to check if the user has ActiveSync enabled [R]
                U_WebDAVSupport = $22B;         // Bool                 Read only variable to check if the user has WebDAV enabled [R]
                U_ArchiveSupport = $446;         // Bool                 Read only variable to check if the user has Archive enabled [R]

                U_SMSContent = $431;       // String  SMS file content [R]

                U_QuarantineEditable = $479;      // Bool                 Read only variable to check if the user has quarantine Editable [R]
                U_ASEditable = $47A;              // Bool                 Read only variable to check if the user has antispam Editable [R]
                U_SIPEditable = $47B;            // Bool                 Read only variable to check if the user has SIP Editable [R]
                U_AVEditable = $47C;             // Bool                 Read only variable to check if the user has antivirus Editable [R]
                U_IMEditable = $47D;             // Bool                 Read only variable to check if the user has instant messaging Editable [R]
                U_GWEditable = $47E;             // Bool                 Read only variable to check if the user has groupware Editable [R]
                U_SyncMLEditable = $47F;         // Bool                 Read only variable to check if the user has syncML Editable [R]
                U_FTPEditable = $480;         // Bool                 Read only variable to check if the user has FTP Editable [R]
                U_SMSEditable = $481;         // Bool                 Read only variable to check if the user has SMS Editable [R]
                U_ActiveSyncEditable = $482;         // Bool                 Read only variable to check if the user has ActiveSync Editable [R]
                U_WebDAVEditable = $483;         // Bool                 Read only variable to check if the user has WebDAV Editable [R]
                U_ArchiveEditable = $484;         // Bool                 Read only variable to check if the user has Archive Editable [R]




		// Rules
		U_BlackWhiteFilter = $01;	// Bool			Use Rules
		U_RulesContentXML = $08;               // String                Rules content xml [D]

                U_IMAPMailbox = $1A;            // String               IMAP mailbox settings

                U_PasswordExpired = $102;       // Bool
                U_MailboxQuota = $103;          // Int [R]
                U_MailboxSize = $104;           // Int [R]

                U_ActivationKey_OutConn = $316;  // String [D]
                U_ActivationKey_Desktop = $317; // String [D]
                U_Client_Connector = $318;       // Bool
                U_Client_Desktop = $319;        // Bool
                U_SIP_CallTransfer = $343;      // String
                U_SMS_SentLastMonth =$35E;      // Int                  Number of SMS sent last month, only valid if Policy for SMS is "use account options" [R]
                U_SMS_SentThisMonth =$35F;      // Int                  Number of SMS sent this month, only valid if Policy for SMS is "use account options" [R]
                U_SMS_SendLimit =$45A;      // Int                      Number of SMS allowed to send this month [R]

	// User Group

		// Group
  		G_ListFile = $73;		// String		List file
      G_ListFile_Contents = $471; // String

                G_Name = $02;                   // String               Folder name
                G_Description = $05;            // String               Description

                G_GroupwareShared = $9D;        // Bool                 Groupware shared
                G_GroupwareMembers = $100;      // Bool                 Groupware members address book
                G_GroupwareMailDelivery = $101; // Bool                 Groupware mail delivery
                G_GroupwareDefaultRights = $9E; // String               Groupware default rights

		// Message
		G_Moderated = $7A;            	// Int			Moderated mode
                        // 0 - None
                        // 1 - Client moderated
                        // 2 - Server moderated
  		G_ModeratedPassword = $7B;    	// String		Password
  		G_ListBatch = $91;            	// Int			Max # of messages sent out in 1 minute

                G_AddRootAdmin = $334;           // String              Write only property, adds full ACL rights on root folder

  		// Rules
		G_BlackWhiteFilter = $01;  	// Bool			Use Rules

	// Mailing List Accounts

		// Mailing list
  		M_Alias = $03;                	// String		Alias
  		M_Name = $02;		        // String		Description
  		M_OwnerAddress = $70;         	// String		Owner address
  		M_SendAllLists = $77;         	// Int			Members source
			// 0 - List file
			// 1 - All current domain users
			// 2 - All system users
			// 3 - All domain administrators
			// 4 - All system administrators
			// 5 - Members from ODBC
  		M_ListFile = $73;      		// String		Path to list file
      M_ListFile_Contents = $472; // String

                M_GroupwareDefaultRights = $9E; // String               Groupware default rights

  		M_ODBC = $95;         		// String		ODBC connection
			// DSN,user,pwd,server,type
                M_SQL = $9C;                    // String               SQL statement

		// Message
  		M_SetSender = $83;            	// Int			Set From or Reply-to headers to sender
			// 0 - Off
			// 1 - Set From: to sender
			// 2 - Set Reply-To: to sender
  		M_SetValue = $7F;            	// Int			Set From or Reply-to headers to value
			// 0 - Off
			// 1 - Set From: to value
			// 2 - Set Reply-To: to value
  		M_ValueMode = $84;            	// Bool			Order of "header value" mode
			// 0 - From: header set to value
			// 1 - Reply To: header set to value
		M_HeaderValue = $80;          	// String		From or Reply-to headers value
			// FromValue|ReplyToValue
  		M_SeparateTo = $8D;           	// Bool			Set Recipients to To: header
  		M_AddToSubject = $85;         	// String		Add to Subject value
  		M_AddToHeader = $98;         	// String		Add headers value
  		M_ListSender = $8C;           	// Int			Originator
			// 0 - Blank
			// 1 - Sender
			// 2 - Owner
  		M_HeaderFile = $78;           	// String		Header file
  		M_FooterFile = $79;           	// String		Footer file

		// Security
  		M_MembersOnly = $82;          	// Bool			Only members can post new messages
		M_Moderated = $7A;            	// Int			Moderated mode
                        // 0 - None
                        // 1 - Client moderated
                        // 2 - Server moderated
  		M_ModeratedPassword = $7B;    	// String		Moderated password
  		M_AllowSubscribers = $96;       // String		Allow subscribers file
  		M_DefaultRights = $9B;        	// Int			Default rights
			// 0 - Receive & post
			// 3 bits - 1st (Receive), 2nd (Post), 3rd (Digest)
  		M_MaxList = $7D;              	// Bool			Enable Maximum message size
	 	M_MaxListSize = $7E;          	// Int			Maximim message size value (kB)
  		M_DenyEXPNList = $7C;         	// Bool			Deny EXPN

		// Other
  		M_SendToSender = $75;         	// Bool			Send copy to Sender
  		M_CopyToOwner = $71;          	// Bool			Forward copy to owner
  		M_DigestConfirmed = $72;      	// Bool			Digest mailing list
		M_ListSubject = $8B;            // Bool			Process mailing list variables
		M_Personalized = $92;         	// Bool			Personalized mailing list
		M_RemoveDead = $90;           	// Bool			Remove dead email addresses
		M_EditSentDate = $350;         	// Bool			Edit date in message header in moment it goes into outgoing queue
  		M_ListBatch = $91;            	// Int			Max # of messages sent out in 1 minute
  		M_NotifyJoin = $8F;           	// Bool			Notify owner - Join
  		M_NotifyLeave = $99;           	// Bool			Notify owner - Leave
  		M_SubListFile = $76;          	// String		Join file
  		M_LeaveFile = $97;         	// String		Leave file

		// Rulest
	  	M_BlackWhiteFilter = $01;     	// Bool			Use Rules

                M_MaxMembers = $9F;             // Int                  Max members
                M_LDAPSync = $106;              // Bool                 LDAP sync
                M_CheckMailbox = $42F;          // Bool                 Do not deliver to members with exceeded quotas

	// List server

		// List server
  		L_Alias = $03;                	// String		Alias
  		L_Name = $02;		        // String		Description
  		L_OwnerAddress = $70;         	// String		Owner address

  		L_SendAllLists = $77;         	// Int			Members source
			// 0 - List file
			// 1 - All domain mailing lists

  		L_ListFile = $73;      		// String		Path to list file
      L_ListFile_Contents = $474; // String
  		L_DigestConfirmed = $72;      	// Int			Subscription
			// 0 - No confirmation
			// 1 - User confirmation
			// 2 - Owner confirmation
		L_ListSubject = $8B;            // Bool			Commands in subject
  		M_JoinR = $86;                	// Bool			Join right
  		M_LeaveR = $87;               	// Bool			Leave right
		M_ListsR = $88;               	// Bool			Lists right
		M_WhichR = $89;              	// Bool			Which right
		M_ReviewR = $8A;              	// Bool			Review right
		M_VacationR = $9A;            	// Bool			Vacation right
		M_WLR = $93;         		// Bool			Whitelist right
		M_BLR = $94;         		// Bool			Blacklist right

		M_DeliverExternally = $88;    	// Bool			Deliver externally

		// Options
		L_Moderated = $7A;            	// Bool			Moderated list server
  		L_ModeratedPassword = $7B;    	// String		Moderated password
  		M_HelpFile = $81;             	// String		List server help file
  		L_ListSender = $8C;           	// Int			Originator
			// 0 - Blank
			// 1 - Sender
			// 2 - Owner
  		L_MaxList = $7D;              	// Bool			Suppress command responses

		// Rules
	  	L_BlackWhiteFilter = $01;     	// Bool			Use Rules

		// Other
  		M_ListServer = $74;           	// Bool			List server vs mailing list

	// Executable Accounts

		// Executable
  		E_Alias = $03;                	// String		Alias
  		E_Name = $02;		        // String		Description
  		E_Application = $50;            // String		Application
  		E_ExecType = $53;             	// Int			Application type
			// 0 - Executable
			// 1 - StdCall library
			// 2 - Cdeecl library
			// 3 - URL
  		E_Parameters = $51;           	// String		Application parameters
  		E_ExecPass = $54;             	// String		Password
  		E_ExecForwardCopy = $52;      	// String		Forward to address

		// Rules
	  	E_BlackWhiteFilter = $01;     	// Bool			Use Rules

        // Resources

                S_Type = $322;                  // Int          (rtRoom, rtEquipment)
                S_Unavailable = $323;           // Bool
                S_Manager = $324;               // String
                S_AllowConflicts = $325;        // Bool
                S_OrganizersFile = $326;        // String
                S_OrganizersFile_Contents  = $473; // String
                S_NotificationToManager = $34F; // Bool

	// Remote Accounts

		//Remoteaccount
                RA_Enabled = $225;           	// Bool			Enabled
		RA_Name = $E0;                	// String		Name
  		RA_Server = $E2;              	// String		Server
  		RA_IMAP = $F5;                	// Bool			Server type
			// 0 - POP3
			// 1 - IMAP
  		RA_UserName = $E3;            	// String		Username
  		RA_Password = $EA;            	// String		Password
  		RA_APOP = $F2;                	// Bool			Login using APOP
  		RA_TLSSSL = $F7;              	// Int			TLS/SSL
			// 0 - Detect TLS/SSL
			// 1 - Direct TLS/SSL
			// 2 - Disable TLS/SSL
  		RA_ForwardTo = $E1;           	// String		Forward to address
  		RA_Schedule = $F6;            	// Schedule		Remote account schedule

		// Options
                RA_NotifyAdmin = $F9;           // Bool                 Notify administrator of session problems
  		RA_Dedupe = $EF;              	// Bool			Dedupe collected emails
  		RA_LeaveMessagesOnServer = $F3; // Bool			Leave messages on server
  		RA_DeleteOlder = $F0;         	// Bool			Delete messages older than (Days)
  		RA_DeleteCount = $F1;         	// Int			Delete if more than (Messages)
  		RA_ExtraForward = $E5;        	// String		Forward extra copy to address
  		RA_ConvertDomains = $ED;      	// Bool			Convert domain names
	  	RA_Routing = $EE;             	// Bool			Email address routing

		// Domain POP
  		RA_DomainPOP = $E4;           	// Bool			Domain POP
  		RA_NoReceived = $E7;          	// Bool			Do not processed Received: header
  		RA_ReceiveAll = $EC;          	// Bool			Stop parsing if Received: yields a local address
  		RA_XEnvelopeTo = $E8;         	// Bool			Parse these headers
  		RA_NoNames = $E9;             	// Bool			Real name address matching
  		RA_MatchEmail = $E6;          	// String		If email:

                RA_DomainString = $EB;          // String               Domain it belongs to
                RA_LeaveMessageFile = $F4;      // String               Path to file to keep uids
                RA_Backup = $F8;                // String               Structure backup
                RA_RulesContentXML = $FA;       // String               Rules xml

	// Static Route Accounts

		// Static route
  		R_Alias = $03;                	// String		Alias
  		R_Name = $02;		        // String		Description
  		R_Activity = $C0;             	// Int			Action
			// 0 - Forward to address
			// 1 - Forward to domain
			// 2 - Forward to host
			// 3 - Delete
			// 4 - Deliver to this domain
  		R_ExternalDomain = $C5;       	// Bool			Forward
  		R_ActivityValue = $C1;        	// String		Value
  		R_SaveTo = $C6;               	// String		Forward to address
		R_ExternalFilter = $C3;       	// Int			Filter
			// 0 - Filter
			// 1 - External
			// 2 - All
  		R_FilterFile = $C2;           	// String		Filter file
  		R_ExternalFilterFile = $C4;   	// String		External filter file
		R_ExternalFilterType = $C7;   	// Int			External filter type
			// 0 - StdCall library
			// 1 - Cdecl library
			// 2 - Executable
			// 3 - URL


	// Notification Accounts

		// Notification
  		N_Alias = $03;                	// String		Alias
  		N_Name = $02;		        // String		Description
  		N_NotifyTo = $A0;          	// String		Notify to:
  		N_IMNotification = $AE;       	// Bool			IM notification
  		N_Size = $A2;                 	// Int			Max message size (Bytes)
  		N_Count = $AC;             	// Int			Split to multiple messages (Messages)
  		N_FilterType = $B3;             // Int			Filter
			// 0 - All
			// 1 - None
			// 2 - Filter
  		N_Send = $A8;                 	// Bool			Send
  		N_FilterFile = $AD;        	// String		Filter file path

		// Other
  		N_IntoSubject = $A1;       	// Bool			Insert information into subject
  		N_SendTo = $A3;               	// Bool			Insert To: header
  		N_SendFrom = $A4;             	// Bool			Insert From: header
  		N_SendSubject = $A5;          	// Bool			Insert Subject
		N_SendDateTime = $A7;         	// Bool			Insert Date/Time
  		N_SendBody = $A6;             	// Bool			Insert Body
  		N_From = $B2;              	// String		From:
  		N_Subject = $AF;           	// String		Subject
  		N_Body = $B0;              	// String		Body
  		N_File = $B1;              	// String		Text file
  		N_ForwardCopy = $A9;       	// String		Forward to:
  		N_Sender = $AB;            	// Int			Originator
			// 0 - Empty
			// 1 - Sender
			// 2 - Owner

		// Rules
	  	N_BlackWhiteFilter = $01;     	// Bool			Use Rules


	// Catalog Accounts 

		// Catalog
  		T_Alias = $03;                	// String		Alias
  		T_Name = $02;		        // String		Description
  		T_CatalogPass = $D0;          	// String		Password
		T_CatalogSubject = $D1;       	// Bool			Commands in subject
  		T_CatalogFile = $D5;          	// String		Catalog file

		// Other
  		T_CatalogGet = $D2;           	// Bool			Get right
  		T_CatalogDir = $D3;           	// Bool			Dir right
  		T_CatalogSendTo = $D6;        	// Bool			SendTo right
  		T_CatalogSender = $D4;        	// Int			Originator
			// 0 - Empty
			// 1 - Sender
			// 2 - Owner

		// Rules
	  	T_BlackWhiteFilter = $01;     	// Bool			Use Rules

///////////////////
// Configuration //
///////////////////

// Version & License

	C_Version = $1000;      				// String	Server version [R]
        C_SettingsVersion = $31A;                               // String       Settings version [R]
        C_Date = $1004;                                  // String              Server release date [R]
        C_Backup = $1001;                                       // String [D]
        C_OS     = $1002;                                       // Bool		Server OS version [R]
		// 0 - Windows
		// 1 - Linux

        C_TimeZone = $1003;                                     // Int          Time zone in seconds [R]

	C_SuiteType = $15;           				// Int		Mail server license type [R]
		// 1 - Pro
		// 2 - Standard
		// 3 - Lite

	C_InstallPath = $10A;                      		// String	Mail server installation path [R]
        C_ConfigPath = $AA;		                        // String	Path to Config folder [R]
        C_WebPath = $200;                                       // String [R]
        C_SpamPath = $202;                                      // String [R]
        C_CalendarPath = $203;                                  // String [R]
        C_PathServiceID = $201;                                 // String [R]

	C_GUI_RequireAuth = $D0;                            	// Bool		Require Authentication to access Admin console
	C_GUI_SafeConfirm = $40;               			// Bool		Use Safe confirmation
  C_GUI_ShowSortingString = $4A2;             // Bool  If set to true, it is possible to edit sorting string on tab with user vcard

	C_License_XML = $AB;              			// String	XML decrypted license [R] [D]
	C_License = $A9;                  		        // String	Server license (read/export and add new license) [D]
        C_LicenseStatus = $440;                                 // Int          License status (lsSuccess, lsEvaluation, lsReferenceMismatch, lsRevalidation, lsExpired, lsNone, lsBuildDate)
        C_License_Modules_Report_Email = $495;                  // String       Gnerate detailed XML report about "used seats" and send it to this email

        C_Reference = $131;                                     // String       Server reference key [R]
        C_OnlineLicense = $169;                                 // String       Retrieve online license using Order ID
        C_ObtainTrialLicense = $489;                            // String       Registers trial license, value have to be "Name;Email;Company;Address;ZIP;CountryCode;Phone"

        C_SettingsTime = $243;                                  // Int          Unix timestamp of settings creation [R]
        C_EvalExpirationTime = $244;                            // Int          Unix timestamp of evaluation expiration [R]

// Accounts

	// Global Settings
		
		// Accounts
		C_Accounts_Global_Accounts_UserStat = $74;      // Bool		Enable User statistics
		C_Accounts_Global_Accounts_UseDefaults = $4D;	// Bool		Use Account defaults
                C_Accounts_Global_Accounts_DisableCache = $1A4; // Bool		Disables account caching
                C_Accounts_Global_Accounts_AccountCache = $1A8; // Int          Maximal number of cached items per domain. Domains wirh less than this number accounts will cache every account. Greater domains will check only recently accessed accounts (such cache can not be used for looping over all domain members)

                C_Accounts_Global_Accounts_Disable_Account_Change_Journal = $475; // Bool Disables database journal tracking changes in accounts , the journal is used for faster update of account cache - only changed accounts are updated


                C_Accounts_Global_Accounts_DirectoryCacheWaveSleep = $425;// Int number of miliseconds to wait after wave processes WaveSafecount items, default = 0, which means automated sophisticated choice
                C_Accounts_Global_Accounts_DirectoryCacheWaveSafeCount = $427;// Int number of items to process before waiting, default = 0, which means automated sophisticated choice
                C_Accounts_Global_Accounts_DirectoryCacheConnectionString = $458;// String Connection string to directory cache database
                C_Accounts_Global_Accounts_DirectoryCacheExclusiveLocking = $49D; // Bool If set to true, the only one quaery against the directory cache is done at a time  (changing requires restart of all services)

             		C_System_Log_Services_DirectoryCache = $492;		// Int		Directory Cache logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
			// 3 - Debug & Summary
      // 4 - Extended


                C_Accounts_Global_Accounts_MaintenanceLog = $1BD; // Bool       Maintenance log
                C_Accounts_Global_Accounts_DeliveryReports = $34D; // Bool       Delivery reports

                C_Accounts_Global_Distributed_Accounts_Cache_Enabled = $34A;    // Bool	enables distributed domains accounts caching
                C_Accounts_Global_Distributed_Accounts_Cache_Max = $34B;        // Int  Maximal Number of cached items
                C_Accounts_Global_Distributed_Accounts_CacheExpire = $34C;      // Int  cache expiration in seconds

                C_System_Services_SMTP_Rewrite_Backup_Recipients = $461;        // Bool if set to false, sending to aliases of backup and distributed domains does not rewrite recipients domain with the domain where the alias points to

		// Domains
		C_Accounts_Global_Domains_UseDiskQuota = $3F;   // Bool		Use Domain disk quota
		C_Accounts_Global_Domains_UseUserLimits = $A0;  // Bool		Use Domain user limits
		C_Accounts_Global_Domains_UseDomainLimits = $1EC;  // Bool		Use Domain limits
		C_Accounts_Global_Domains_UseExpiration = $F2;  // Bool		Use Domain expiration
		C_Accounts_Global_Domains_OverrideGlobal = $C3; // Bool		Override global limits
		C_Accounts_Global_Domains_Literals = $B3;       // Bool		Enable Domain literals
		C_Accounts_Global_Domains_DomainKeys = $13D;   	// Bool		Enable DomainKeys support
		C_Accounts_Global_Domains_Hostname = $196; 	// Bool		Use domain hostnames for outgoing msgs
		C_Accounts_Global_Domains_IPAddress = $197; 	// Bool		Use domain IP address for outgoing msgs
		C_Accounts_Global_Domains_WelcomeMsgs = $45;	// Bool		Use Welcome messages
		C_Accounts_Global_Domains_WarnMailboxUsage = $D3; // Int	Warn when mailbox size exceeds (%)
                C_Accounts_Global_Domains_WarnDomainSize = $167; // Int          Warn when domain size exceeds (%)

                C_Accounts_Global_ActiveDirectorySyncInterval = $1D7; // Int    Minutes interval
                C_System_ADSyncLogType = $419; // Int		                AD synchronization logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
			// 3 - Debug & Summary

                C_System_ADSyncIgnoreSearchError = $433;        // Bool		If AD synchronization search returns error, but still some data were returned, Synchronization performs no delete operation by default. Setting this to true enables delete operations for this cases.
                C_System_ADSyncMaxDeleteThreshold = $434;       // Int          If set to value greater than 0, AD sync performs no delete if it should delete more accounts than this value
                C_System_ADSyncDisableVCardSync = $485;         // Bool   If set, AD sync will not fill in user's Card with information from AD server

                C_System_KerberosLogType = $42A; //Int		                Kerberos Authentication logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
			// 3 - Debug & Summary


                // LDAP
		C_Accounts_Global_LDAP_Synchronize = $D6;        // Bool	LDAP user synchronization
                C_Accounts_Global_LDAP_Host = $1CD;             // String
                C_Accounts_Global_LDAP_Base = $1CE;             // String
                C_Accounts_Global_LDAP_User = $1CF;             // String
                C_Accounts_Global_LDAP_Pass = $1D0;             // String
                C_Accounts_Global_LDAP_UseWindowsDLL = $344;      // Bool       windows ldap library instead of openldap is used
                C_Accounts_Global_LDAP_UseNTLMAuth = $449;          // Bool       use NTLM instead of plain auth, requires C_Accounts_Global_LDAP_UseWindowsDLL to be enabled

                C_Accounts_Global_LDAP_PassChangeDisable = $429; // Bool        Disable password changing in LDAP

                // Console
                C_Accounts_Global_Console_ShowAccounts = $145;  // Int		Number of shown accounts in a domain
                C_Accounts_Global_Console_AccountsPosition = $144; // Int	Database account display start position
                C_Accounts_Global_Console_DomainDescription = $3A; // Int	Domain list display mode
			// 0 - Domain
			// 1 - Description + Domain
			// 2 - Domain + Description
                C_Accounts_Global_Console_AccountDescription = $315; // Int	Account display mode


	// Policies

		// Login Policy
		C_Accounts_Policies_Login_Enable = $F3;		// Bool		Enable Login policy
		C_Accounts_Policies_Login_Attempts = $F4;       // Int		Number of failed logins
		C_Accounts_Policies_Login_BlockPeriod = $F5;	// Int		Block user login for (Min)
		C_Accounts_Policies_Login_LoginSettings = $73;  // Bool		Login settings mode
			// 0 - login with username
			// 1 - login with full email address
                C_Accounts_Policies_Login_Block = $1F4;         // Bool
			// 0 - Do not block but delay authentication
			// 1 - Block account for specified time
		C_Accounts_Policies_Login_ConvertChars = $79;   // Bool		Convert chars %/ to @ in username

                C_Accounts_Policies_Login_IPRestriction = $134; // Bool         Enables account IP restriction

                C_Accounts_Policies_Login_DisableDomainIPLogin = $1F8; // Bool


                C_Accounts_Policies_SuperUser = $1EA;             // Bool
                C_Accounts_Policies_SuperUserPassword = $1EB;     // String

                C_Accounts_Policies_Login_AuthWISIDDisable = $215; // Bool

		// Password policy
		C_Accounts_Policies_Pass_Enable = $9B; 		// Bool		Enable Password policy
		C_Accounts_Policies_Pass_MinLength = $9C;    	// Int		Min password length
		C_Accounts_Policies_Pass_Digits = $9D;          // Int		Number of numeric chars in password
		C_Accounts_Policies_Pass_NonAlphaNum = $F7;	// Int		Number of non alphanumeric characters
		C_Accounts_Policies_Pass_UserAlias = $B7;       // Bool		Check password against username/alias
		C_Accounts_Policies_Pass_Expiration = $FA;      // Bool		Enable password expiration
		C_Accounts_Policies_Pass_ExpireAfter = $FB;	// Int		Expire after (Days)
		C_Accounts_Policies_Pass_Notification = $240;   // Bool		Enable Notification of expiration
		C_Accounts_Policies_Pass_NotifyBefore = $241;	// Int		Notify before (Days)
		C_Accounts_Policies_Pass_DenyExport = $F8;      // Bool		Passwords cannot be read or exported
		C_Accounts_Policies_Pass_AllowAdminPass = $F9;  // Bool		Allow Admin's password to be exported
                C_Accounts_Policies_Pass_Encrypt = $CD;         // Bool		Password database encryption
                C_Accounts_Policies_Pass_Alpha = $1E9;          // Int          Number of alpha characters
                C_Accounts_Policies_Pass_UpperAlpha = $417;     // Int     Number of uppercase alpha characters

                C_Accounts_Policies_Auth_Schemes = $435;            // String       Allowed authentication SASL schemes
                C_Accounts_Policies_Auth_ToMailFrom = $436;         // Bool         Make authenticated user the actual sender
                C_Accounts_Policies_Auth_DisablePlain = $437;       // Bool         Disable plain authentication in all services


// System

	// Services
    C_System_FileName_Ends_With_ServerId  = $486; // Bool If enabled - ServerId (see Load Ballancing) will appear at the end of generated filenames and not at the beginning

		C_System_Services_Firewall = $5B;          	// Bool		Restrict access to all services
		C_System_Services_BindIPAddress = $27;  	// String	IP addresses to bind services to

		// SMTP service
	   	C_System_Services_SMTP_Port = $1B;  		// Int		SMTP service port
		C_System_Services_SMTP_SSLPort = $3B;           // Int		SMTP service SSL port
		C_System_Services_SMTP_AltPort = $13;		// Int		SMTP service alternative port
 		C_System_Services_SMTP_Traffic = $103;          // Bool		Enable SMTP traffic logs
		C_System_Services_SMTP_IPList = $5D;            // String	List of Denied/Granted IPs
		C_System_Services_SMTP_AccessMode = $5C;	// Bool		Service Policy
			// 0 - Deny
			// 1 - Grant
                C_System_Services_SMTP_Startup = $251;          // Int          (ssAutomatic, ssManual)
 		C_System_Services_SMTP_ThreadCache = $51;       // Int		SMTP service Thread cache
		C_System_Services_SMTP_MonitorData = $14F;      // Int          Monitor increased traffic
		C_System_Services_SMTP_MonitorConn = $150;      // Int          Monitor number of increased connections
		C_System_Services_SMTP_MaxInConn = $112;  	// Int		Max number of Incoming connections
		C_System_Services_SMTP_MaxOutConn = $50;        // Int		Max number of Outgoing connections
		C_System_Services_SMTP_Bandwidth = $11F;        // Int		Max transfer bandwidth (kB/s)

		// POP3 service
		C_System_Services_POP3_Port = $19; 	  	// Int		POP3 service port
		C_System_Services_POP3_SSLPort = $1A;		// Int		POP3 service SSL port
		C_System_Services_POP3_Traffic = $104;          // Bool		Enable SMTP traffic logs
		C_System_Services_POP3_IPList = $5F;            // String	List of Denied/Granted IPs
		C_System_Services_POP3_Accessmode = $5E;        // Bool		Service Policy
			// 0 - Deny
			// 1 - Grant
                C_System_Services_POP3_Startup = $252;          // Int          (ssAutomatic, ssManual)
		C_System_Services_POP3_ThreadCache = $52;       // Int		POP3 service thread cache
		C_System_Services_POP3_MaxInConn = $113;        // Int		Max number of Incoming connections
		C_System_Services_POP3_MaxOutConn = $4F;        // Int		Max number of Outgoing connections
		C_System_Services_POP3_Bandwidth = $120;        // Int		Max transfer bandwidth (kb/s)
		C_System_Services_POP3_MonitorData = $151;      // Int          Monitor increased traffic
		C_System_Services_POP3_MonitorConn = $152;      // Int          Monitor number of increased connections
		C_System_POP3_Locking = $31E;                   // Bool         POP3 does not allow multiple login of one account

		// IMAP service
		C_System_Services_IMAP_Port = $1F;            	// Int		IMAP service port
 		C_System_Services_IMAP_SSLPort = $1C; 		// Int		IMAP service SSL port
		C_System_Services_IMAP_Traffic = $105;          // Bool		Enable IMAP traffic logs
		C_System_Services_IMAP_ThreadCache = $12B;      // Int		IMAP service thread cache
		C_System_Services_IMAP_MaxInConn = $114;        // Int		Max number of Incoming connections
		C_System_Services_IMAP_MaxOutConn = $12C;       // Int		Max number of Outgoing connections
		C_System_Services_IMAP_Bandwidth = $121;        // Int		Max transfer bandwidth (kB/s)
		C_System_Services_IMAP_IPList = $127;           // String	List of Denied/Granted IPs
		C_System_Services_IMAP_Accessmode = $128;       // Bool		Service Policy
		C_System_Services_IMAP_MonitorData = $153;      // Int          Monitor increased traffic
		C_System_Services_IMAP_MonitorConn = $154;      // Int          Monitor number of increased connections

                C_System_Services_IMAP_FileNameFlags = $1C7;    // Bool
                C_System_Services_IMAP_IndexedSearch =$32E;     // Int          Integrate IMAP search with indexing service
                        // 0 - No Integration
                        // 1 - Windows Desktop Search

                C_System_Services_IMAP_RSSInterval = $340;     // Int          Integrate IMAP search with indexing service
                C_System_Services_IMAP_ForceFullsync =$426;    // Bool          Obsolete, only for backward compatibility
                C_System_Services_IMAP_CopyBWFunction =$45B;    // Bool         Copy/Move from Inbox to Spam indexes e-mail to Blacklist, Copy/Move from Spam to Inbox indexes e-mail to WhiteList
                C_System_Services_IMAP_FullSyncInterval =$48C;    // Int        (hours) Determines how often is IMAP going to sync contents of imapindex.dat with filesystem. When the time for next sync is evalueted, random number between 0 and this value is added to this value. The full item sync should be needed only if some files were added directly on filesystem.
                C_System_Services_IMAP_FreeMemoryOnIdle =$4A1;    // Bool           When IDLE is performed, information about all items are freed from memory and reloaded only after changes are detected or when idle is terminated

    C_System_Services_SmallFilesCache_Size = $46E;      // String       Maximal size (in bytes) of cache for small files, (imapindex.dat, flags.dat...), Seto 0 to disable, do not enable on LB scenarios
    C_System_Services_SmallFilesCache_MaxFileSize = $46F;      // Int       Maximal size (in bytes) of file, which will be cached in cache for small files, (imapindex.dat, flags.dat...)
    C_System_Services_SmallFilesCache_DelayWrite= $470;   // Bool     If set to true, cache write operations are not directly done on filesystem, but are procesed in background thread

		// IM service
		C_System_Services_IM_Port = $E1;                // Int		IM service port
		C_System_Services_IM_SSLPort = $E2;		// Int		IM service SSL port
		C_System_Services_IM_AltPort = $BD;             // Int		IM service alternative port
		C_System_Services_IM_Traffic = $106;            // Bool		Enable IM traffic logs
		C_System_Services_IM_IPList = $100;             // String	List of Granted / Denied IPs
		C_System_Services_IM_AccessMode = $FF;          // Bool		Service Policy
			// 0 - Deny
			// 1 - Grant
                C_System_Services_IM_Startup = $253;          // Int          (ssAutomatic, ssManual)
		C_System_Services_IM_ThreadCache = $DE;		// Int		Service thread cache
		C_System_Services_IM_MaxInConn = $118;          // Int		Max number of Incoming connections
		C_System_Services_IM_Bandwidth = $125;          // Int		Max transfer bandwidth (kB/s)
		C_System_Services_IM_MonitorData = $155;        // Int          Monitor increased traffic
		C_System_Services_IM_MonitorConn = $156;        // Int          Monitor number of increased connections

		// Groupware service
		C_System_Services_GW_Port = $B8;                // Int		GW service port
		C_System_Services_GW_Traffic = $107;            // Bool		Enable GW traffic logs
		C_System_Services_GW_IPList = $102;           	// String	List of Denied/Granted IPs
		C_System_Services_GW_AccessMode = $101;         // Bool		Service Policy
			// 0 - Deny
			// 1 - Grant
                C_System_Services_GW_Startup = $254;          // Int          (ssAutomatic, ssManual)
		C_System_Services_GW_ThreadCache = $12A;	// Int		GW service Thread cache
		C_System_Services_GW_MaxInConn = $119;		// Int		Max number of Incoming connections
		C_System_Services_GW_Bandwidth = $126;          // Int		Max transfer bandwidth (kB/s)
		C_System_Services_GW_MonitorData = $157;        // Int          Monitor increased traffic
		C_System_Services_GW_MonitorConn = $158;        // Int          Monitor number of increased connections

		// Control service
		C_System_Services_Control_Port = $1E;         	// Int		Control service port
		C_System_Services_Control_SSLPort = $20;      	// Int		Control service SSL port
		C_System_Services_Control_Traffic = $108;       // Bool		Enable Control traffic logs
		C_System_Services_Control_IPList = $63;         // String	List of Denied/Granted IPs
		C_System_Services_Control_AccessMode = $62;     // Bool		Service Policy
			// 0 - Deny
			// 1 - Grant
                C_System_Services_Control_Startup = $256;          // Int          (ssAutomatic, ssManual)
		C_System_Services_Control_ThreadCache = $53;    // Int		Control service Thread cache
		C_System_Services_Control_MaxInConn = $115;     // Int		Max number of Incoming connections
		C_System_Services_Control_Bandwidth = $122;     // Int		Max transfer bandwidth (kB/s)
		C_System_Services_Control_MonitorData = $159;   // Int          Monitor increased traffic
		C_System_Services_Control_MonitorConn = $15A;   // Int          Monitor number of increased connections

		// FTP service
		C_System_Services_FTP_Port = $10C;              // Int		FTP service port
		C_System_Services_FTP_SSLPort = $10D;           // Int		FTP service SSL port
		C_System_Services_FTP_Traffic = $11A;      	// Bool		Enable FTP traffic logs
		C_System_Services_FTP_IPList = $11B;            // String	List of Granted / Denied IPs
		C_System_Services_FTP_AccessMode = $11C;	        // Bool		Service Policy
			// 0 - Deny
			// 1 - Grant
		C_System_Services_FTP_ThreadCache = $11D;       // Int		Service thread cache
		C_System_Services_FTP_MaxInConn = $116;		// Int		Max number of Incoming connections
		C_System_Services_FTP_MaxOutConn = $11E;	// Int		Max number of Outgoing connections
		C_System_Services_FTP_Bandwidth = $123;         // Int		Max transfer bandwidth (kB/s)
		C_System_Services_FTP_MonitorData = $15B;      // Int          Monitor increased traffic
		C_System_Services_FTP_MonitorConn = $15C;      // Int          Monitor number of increased connections

		// LDAP service
		C_System_Services_LDAP_Enable = $6D;  		// Bool		Enable LDAP service
		C_System_Services_LDAP_Port = $12;              // Int		LDAP service port
		C_System_Services_LDAP_SSLPort = $11;           // Int		LDAP service SSL port
		C_System_Services_LDAP_MaxInConn = $117;        // Int		Max number of Incoming connections
		C_System_Services_LDAP_Bandwidth = $124;        // Int		Max transfer bandwidth (kB/s)

                C_System_Services_Socks_Enabled = $218;            // Bool         Enable Socks server
                C_System_Services_Socks_Port = $219;              // Int          Socks port
                C_System_Services_Socks_MaxInConn = $30D;         // Int
		C_System_Services_Socks_IPList = $30E;            // String
		C_System_Services_Socks_IPGrant = $30F;            // Bool

                // Minger service
                C_System_Services_Minger_Enabled = $345;           // Bool         Enable Minger server
                C_System_Services_Minger_Port = $346;              // Int          Basic Minger port (UDP)
                C_System_Services_Minger_SSLPort = $42E;           // Int          Minger SSL port (TCP)

                C_System_Services_Minger_Logging = $348;           // Bool


                C_System_Services_ExperimentalFastIPC = $46C;  // Bool          Enables experimental IPC server/client


                C_System_AutoDiscover_SMTPType = $367; // Bool
                C_System_AutoDiscover_POP3 = $368; // String
                C_System_AutoDiscover_POP3Type = $369;  // Bool
                C_System_AutoDiscover_IMAP = $36A; // String
                C_System_AutoDiscover_IMAPType = $36B;  // Bool
                C_System_AutoDiscover_XMPP = $36C; // String
                C_System_AutoDiscover_XMPPType = $36D;  // Bool
                C_System_AutoDiscover_SIP = $36E; // String
                C_System_AutoDiscover_SIPType = $36F;  // Bool

	// Logging

		// General
                C_System_Logging_General_AppendFiles = $19A;    // Bool		Append logs to files
		C_System_Logging_General_DeleteOlder = $34;     // Int		Delete logs after (Days)
		C_System_Logging_General_Archive = $1DD;        // Bool
		C_System_Logging_General_ArchiveTo = $1DE;      // String
		C_System_Logging_General_LogCache = $67;	// Int		Logging cache (B)
                C_System_Logging_General_LogRotation = $12D;    // Int          Size of the log file (kB)
		C_System_Logging_General_SystemLogFunction = $7B; // Bool	Send logs to system log function
                C_System_Logging_Syslog_Active = $19B;          // Bool		Send logs to server
                C_System_Logging_Syslog_Server = $19C;          // String	Syslog server name
		C_System_Logging_General_EnableODBCLog = $6C;	// Bool		Enable ODBC logging
		C_System_Logging_General_ODBCLogConn = $6B;	// String		ODBC logging connection
                C_System_Logging_General_LogTimeFormat = $1B9;  // Int          Log time format
                        // 0 - sltfTime
                        // 1 - sltfScientific
                        // 2 - sltfRFC822
                        // 3 - sltfTimeDetailed

    C_System_Logging_General_ExperimentalFastLogging = $46B;  // Bool          Enables experimental file logging mode - everything is sent to control service using pipe connection, from background thread
    C_System_Logging_General_EnableStackTrace = $476;  // Bool          Enables more detailed logging of system exceptions, if enabled, whole stacktrace is logged


                C_System_Logging_Maintenance_Identity = $281;    // String	Thread variable - will be used in maintenance logs as "WHO"

                C_System_Sessions_DisableHistory = $1BF;        // Bool         Disable session history

		// Services
		C_System_Log_Services_SMTP = $64;		// Int		SMTP service logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
			// 3 - Debug & Summary
            // 4 - Extended
		C_System_Log_Services_POP3 = $69;		// Int		POP3 service logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
			// 3 - Debug & Summary
            // 4 - Extended
		C_System_Log_Services_IMAP = $10F;		// Int		IMAP service logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
			// 3 - Debug & Summary
            // 4 - Extended
		C_System_Log_Services_IM = $E0;                	// Int		IM service logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
			// 3 - Debug & Summary
            // 4 - Extended
		C_System_Log_Services_GW = $B1;                	// Int		GW service logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
			// 3 - Debug & Summary
            // 4 - Extended
		C_System_Log_Services_Control = $6E;	        // Int		Control service logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
			// 3 - Debug & Summary
            // 4 - Extended
		C_System_Log_Services_FTP = $10E;		// Int		FTP service logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
			// 3 - Debug & Summary
            // 4 - Extended
		C_System_Log_Services_LDAP = $110;		// Int		LDAP service logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
			// 3 - Debug & Summary
            // 4 - Extended
		C_System_Log_Services_AV = $97;			// Int		AV logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
        	// 3 - Debug & Summary
            // 4 - Extended
                C_System_Log_Services_AS = $15F;                // Int          AS logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
			// 3 - Debug & Summary
                        // 4 - Extended
                C_System_Log_Services_SIP = $18A;               // Int          SIP logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
			// 3 - Debug & Summary
            // 4 - Extended
		C_System_Log_Services_SMS = $210;              	// Int		SMS service logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
			// 3 - Debug & Summary
            // 4 - Extended
		C_System_Log_Services_SyncPush = $213;              	// Int		Push service logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
			// 3 - Debug & Summary
            // 4 - Extended
                C_System_Log_Services_Socks = $310;                     // Int		Socks logging level
			// 0 - None
			// 1 - Debug
			// 2 - Summary
			// 3 - Debug & Summary
            // 4 - Extended


                C_System_Log_MailQueue = $1E4;  // Bool                Debug logging - internal usage only
                C_System_Log_API = $300;  // Bool                      Debug API logging - internal usage only
                C_System_Log_DNS = $30C;  // Bool                      Debug DNS logging - internal usage only
                C_System_Log_Performance = $34E;  // Int               Debug performance - actions exceeding time in seconds
                C_System_Log_Performance_Level = $423;  // Int         Debug performance - level of importance  0 - basic, 10 - brutal


	// Tools
		// Auto backup
		C_System_Tools_AutoBackup_Enable = $6F;  	// Bool		Enable Auto backup
                C_System_Tools_AutoBackup_BackupTo = $140;      // String	Path to backup file
                C_System_Tools_AutoBackup_Password = $1D2;      // String       Password
                C_System_Tools_AutoBackup_Schedule = $141;      // Schedule	Auto backup Schedule
                C_System_Tools_AutoBackup_DeleteAfter = $142;   // Int		Delete backup file after (Days)
		C_System_Tools_IncludeMailDir = $FE;            // Bool		Include mail folder settings to backup
		C_System_Tools_ExcludeLicense = $CC;            // Bool		Do not include license to backup file
                C_System_Tools_Backup_Emails = $1AA;            // Bool         Backup emails
                C_System_Tools_Backup_SkipLarger = $1AB;        // Int          Skip emails larger (MB)
                C_System_Tools_Backup_SkipOlder = $1AC;         // Int          Skip emails older (Days)
                C_System_Tools_Backup_Dirs = $1AD;              // String       Additional directories to backup
                C_System_Tools_Backup_Logs = $1B2;              // Bool         Backup logs
                C_System_Tools_Backup_GWAttach = $294;          // Bool         Backup groupware attachments
                C_System_Tools_Backup_DB_AccountsEnabled = $301;       // Bool
                C_System_Tools_Backup_DB_Accounts = $302;              // String
                C_System_Tools_Backup_DB_ASEnabled = $303;             // Bool
                C_System_Tools_Backup_DB_AS = $304;                    // String
                C_System_Tools_Backup_DB_GWEnabled = $305;             // Bool
                C_System_Tools_Backup_DB_GW = $306;                    // String


		// Mail archive
		C_System_Tools_AutoArchive_Enable = $99;	// Bool		Enable Auto archive
		C_System_Tools_AutoArchive_Path = $9A;		// String	Auto archive path
		C_System_Tools_AutoArchive_DoNotSpam = $224;	// Bool 	Do not archive spam messages
		C_System_Tools_AutoArchive_DeleteOlder = $BA;   // Int		Delete archive older than (Days)
		C_System_Tools_AutoArchive_Outgoing = $143;     // Int (ammAll, ammInbox, ammAllRoot, ammInboxRoot, ammDeleted)
		C_System_Tools_AutoArchive_Backup_Active = $1AE;   // Bool 	Backup archive
                C_System_Tools_AutoArchive_Backup_DeleteOlder = $1B0; // Int    Delete old archive backups
                C_System_Tools_AutoArchive_Backup_File = $1B1; // String        Archive backup file
                C_System_Tools_AutoArchive_Backup_Password = $1D1; // String    Password
                C_System_Tools_AutoArchive_TrailerPath = $309; // String
                C_System_Tools_AutoArchive_IMAPArchiveName = $30A; // String
                C_System_Tools_AutoArchive_IMAPArchive = $30B; // Bool;
                C_System_Tools_AutoArchive_IMAPArchiveSent = $329; // String
                C_System_Tools_AutoArchive_IMAPArchiveInbox = $32A; // String
                C_System_Tools_AutoArchive_UnknownUsers = $33F;   // Bool
                C_System_Tools_AutoArchive_ForwardArchive = $341;   // String
                C_System_Tools_AutoArchive_GroupAccess = $1B6; // String
                C_System_Tools_AutoArchive_RSS = $474; // Bool

		// Atomic clock sync
		C_System_Tools_AtomicClockSync_Enable = $96;	// Bool		Enable Atomic clock sync

		// Watchdog
		C_System_Tools_WatchDog_SMTP = $2E;             // Bool		Enable Watchdog for SMTP
		C_System_Tools_WatchDog_POP3 = $2F;      	// Bool		Enable Watchdog for POP3
		C_System_Tools_WatchDog_IM = $CF;            	// Bool		Enable Watchdog for IM
		C_System_Tools_Watchdog_GW = $AE;	        // Bool		Enable Watchdog for GW
		C_System_Tools_Watchdog_Control = $214;	        // Bool		Enable Watchdog for Control
		C_System_Tools_Watchdog_Int = $31;              // Int		Watchdog Interval
                C_System_Tools_Watchdog_Check_Protocols = $32C; // Bool		Should Watchdog connect on Service Port
                C_System_Tools_Watchdog_Check_IPList = $443; // String   Semicolon separated list of IP's on which will be checked protocols, all must success, not applicable on services with specific IP binding

		// System Monitor
		C_System_Tools_Monitor_Enable = $35; 		// Bool		Enable System monitor
		C_System_Tools_Monitor_ReportAddress = $7C;	// String	Disk monitor report address
		C_System_Tools_Monitor_FreeMem = $F1;           // Int		Alert if free memory drops below (kB)
 		C_System_Tools_Monitor_DiskSize = $55;          // Int		Alert if free disk space drops below (MB)
		C_System_Tools_Monitor_CPUUsagePerc = $EF;      // Int		CPU utilization threshold (%)
		C_System_Tools_Monitor_CPUUsagePeriod = $F0;	// Int		Alert if CPU usage exceeds threshold for (Min)
		C_System_Tools_Monitor_WebThreadPoolThreshold = $363;	// Int		Alert if Maximal waiting time on web threadpools in last 5 minutes exceeds threshold (s)

		// Remote Servers Watchdog
		C_System_Tools_RemoteServer_Enable = $160;      // Bool		Enable Remote server watchdog
		C_System_Tools_RemoteServer_MoreThan = $161;    // Int		Server is down if unreachable for (Min)
		C_System_Tools_RemoteServer_Email = $162;       // String	Report Email address
 		C_System_Tools_RemoteServer_Schedule = $163;    // Schedule	Remote Server Watchdog Schedule
		C_System_Tools_RemoteServer_NotifyAgain = $164; // Bool		Notify when server is back online


		// TCP/IP tunnel
		C_System_Tools_Tunnel_Enable = $CA;   		// Bool		Enable TCP/IP tunnel

                // Migration Tool
                C_System_Tools_DBMigration_FixUTF8 = $298;           // Bool

		//General
	        C_System_Tools_Migration_Active = $16D;         // Bool		Enable Migration
        	C_System_Tools_Migration_Server = $16E;         // String	Migration source host
                C_System_Tools_Migration_MigrateService = $175; // Int		Migration service
			// 0 - Both
			// 1 - POP3
			// 2 - IMAP

                C_System_Tools_Migration_SSLMode = $335;        // Int		Migration service
                        // 0 - Detect TLS/SSL
			// 1 - Direct TLS/SSL
			// 2 - Disable TLS/SSL


                C_System_Tools_Migration_InfoAccount = $16F;    // String	Migration account
	        C_System_Tools_Migration_LogFile = $170;        // String	Path to log file
                C_System_Tools_Migration_PostMigrateScript = $328;  // String   Path to executable to be called after user was created
        	C_System_Tools_Migration_MessageProcessType = $172; // Int	Policy
			// 0 - Standard
			// 1 - Extended alias resolving
			// 2 - Username
                C_System_Tools_Migration_NoXEnvelopeTo = $171;  // Bool		Do not use X-Envelope-To header
                C_System_Tools_Migration_NoReceived = $173;     // Bool		Do not process received header
                C_System_Tools_Migration_MultiDomain = $174;    // Bool		Multidomain migration
                C_System_Tools_Migration_PasswordsOnly = $270;  // Bool		Only passwords are migrated (users already exists)
                C_System_Tools_Migration_DisableExistenceChecking= $351;  // Bool		Disables check of existence before remote validation

		// Statistics
                C_System_Tools_Migration_Stat_Start = $17C;     // Int		Unix time of start [R]
                C_System_Tools_Migration_Stat_TotalUsers = $17A;// Int		Total number of migrated mailboxes [R]
                C_System_Tools_Migration_Stat_Users = $177;     // Int		Number of migrated mailboxes [R]
                C_System_Tools_Migration_Stat_Aliases = $179;   // Int		Number of migrated aliases [R]
                C_System_Tools_Migration_Stat_Messages = $178;  // Int		Number of messages migrated [R]
                C_System_Tools_Migration_Stat_Last = $17D;      // Int		Unix time of last migrated mailbox [R]
                C_System_Tools_Migration_Stat_Errors = $17B;    // Int		Number of migration errors [R]

	// Storage

		// Accounts
		C_System_Storage_Accounts_StorageMode = $75;	// Int (stProfessional, stFileSystem, stODBC)
			// Accounts storage mode
			// 0 - Professional file system
			// 1 - Standard file system
			// 2 - ODBC
		C_System_Storage_Accounts_ProModeCache = $E4;	// Int		Professional file system memory cache
		C_System_Storage_Accounts_ODBCConnString = $61;	// String	ODBC connection string
		C_System_Storage_Accounts_ODBCMultithread = $B0;// Bool		Use Multithreaded ODBC
                C_System_Storage_Accounts_ODBCMaxThreads = $1E3; // Int
                C_System_Storage_Accounts_DBCacheCount = $366; // Int


		// Directories
		C_System_Storage_Dir_MailPath = $17;		// String	Path to mail folder
		C_System_Storage_Dir_TempPath = $16;		// String	Path to temp folder
		C_System_Storage_Dir_LogPath = $18; 		// String	Path to log folder

                C_System_Storage_Mailbox_UseSorting = $12F;     // Bool         Enables mailbox path alphabetical sorting
                C_System_Storage_Mailbox_PrefixLen = $130;      // Int          Number of characters from alias in path prefix
                C_System_Storage_Mailbox_GroupedPrefix = $337; // Int           Number of grouped characters in path prefix

		// Load Balancing
		C_System_Storage_LB_ServerID = $D2;      	// String	Server ID
		C_System_Storage_LB_AutoCheckConfig = $129;     // Bool 	Periodically check if settings have been changed and auto reload

                // Default charset for direct mysql client library - older icewarps (version 5 and older) used to be set to latin1 for Mysql connection. On IceWarp 10 it uses utf8 by default. If your DB is in latin 1, in a fresh install you need to set this to latin1 or convert your DB to utf8
                C_System_MySQLDefaultCharset = $216;            // String
                C_System_SQLLogType = $221;                     // Int          Type of SQL logging
		// 0 - Do not log SQL queries
		// 1 - Log all SQL Queries
		// 2 - Log only Failed SQL Queries
		// 3 - Log SQL connections maintenance

	// Internet Connection
	C_System_Conn_Type = $7E;                  		// Int		Connection mode
		// 0 - Network connection
		// 1 - Dial-up
		// 2 - Dial-up on demand router
	C_System_Conn_UpName = $7F;                  		// String	Connection name
	C_System_Conn_UpUsername = $80;   	    		// String	Username
	C_System_Conn_UpPassword = $81; 	                // String	Password
	C_System_Conn_UpHangUpAfter = $82; 			// Int		Hang up after (sec)
	C_System_Conn_UpOlderthan = $21;		        // Int		Connect if msg waits for more than (Min)
	C_System_Conn_DialOnDemandExceed = $68;                 // Int		Connect if number of msgs exceeds
	C_System_Conn_DialOnDemandHeader = $70;                 // Bool		Connect if message with this header
	
	C_System_Conn_Schedule = $95;          			// Schedule	Connection schedule
	C_System_Conn_GlobalSchedule = $176;          	    	// Schedule	Global schedule

        C_System_Conn_Proxy = $338;                             // String

	// Advanced

		// Extensions
		C_System_Adv_Ext_DisableSSLTLS = $AF;           // Bool		Disable SSL/TLS
		C_System_Adv_Ext_EnableIPv6 = $B4; 		// Bool		Enable IPv6 Protocol
		C_System_Adv_Ext_ChangePassServer = $CB;	// Bool		Enable Change password server
		C_System_Adv_Ext_DaytimeServer = $C8; 		// Bool		Enable Daytime server
                C_System_Adv_Ext_DayTimePort = $13B;            // Int          Daytime port
		C_System_Adv_Ext_DisableMultiCPU = $4C;         // Bool		Disable Multiple CPU
                C_System_Adv_Ext_SNMPServer = $139;             // Bool         Enable SNMP server
                C_System_Adv_Ext_SNMPPort = $13C;               // Int          SNMP port

                C_System_Adv_Ext_SSLServerMethod = $1F5;        // Int (Default, smSSLv2_method, smSSLv23_method, smSSLv3_method, smTLSv1_method)
                C_System_Adv_Ext_SSLClientMethod = $1F6;        // Int (Default, smSSLv2_method, smSSLv23_method, smSSLv3_method, smTLSv1_method)
                C_System_Adv_Ext_SSLCipherList   = $286;        // String       List of supported ciphers according to (http://www.openssl.org/docs/apps/ciphers.html#)

		// Protocols
		C_System_Adv_Protocols_SessionTimeOut = $0C;    // Int		Session timeout
		C_System_Adv_Protocols_ResponseDelay = $0D;     // Int		Protocol response delay
		C_System_Adv_Protocols_MaxBadCommands = $4E; 	// Int		Max number of bad commands
		C_System_Adv_Protocols_BackLog = $54;           // Int		Listen back logs
		C_System_Adv_Protocols_DNSTimeout = $48;        // Int		DNS Timeout
		C_System_Adv_Protocols_DNSCache = $E6;          // Bool		Use DNS smart cache
		C_System_Adv_Protocols_DNSRetry = $12E;         // Int		DNS retries
		C_System_Adv_Protocols_DNSCacheLimit = $132;    // Int		DNS cache items limit
                C_System_Adv_Protocols_IMAPTimeout = $1F0;      // Int          IMAP timeout
                C_System_Adv_Protocols_HTTPTimeout = $31F;      // Int          HTTP timeout
                C_System_Adv_Protocols_XMPPTimeout = $339;      // Int          XMPP timeout
                C_System_Adv_Protocols_SMTPClientTimeout = $424;// Int          timeout for SMTP client sessions

                // Notification
                C_System_Adv_Notification_Active = $1F1;        // Bool         Notification messages active
                C_System_Adv_Notification_Host = $1F2;          // String       Notification messages host

                // Rename of default folders
                C_System_Adv_Rename_Default_Folders = $352;     // String       Write Only - Renames default folders, accepts URL-encoded, UTF-8 list of form where=value1&events=value2&contacts=value3&tasks=value4&notes=value5&journals=value6&files=value7&drafts=value8&trash=value9&sent=value10 [R]
                C_System_Adv_Process_New_Day = $462;            // Bool         Write Only - Sends signal to all servicess to process the new day procedures
                C_System_Adv_Dump_Memory = $4A0;                // Bool         Write Only - Sends signal to all servicess to dump memory use info (only working in special builds)

                // use e.g. tool set system C_System_Adv_Rename_Default_Folders "where=*&sent=Odeslan"

                C_System_Debug_DisableStartServerServices = $418; // Bool       Disables startserver services (Java, CommTouch, LDAP and others)

// Mail service

        // All mail services
        C_Mail_SMTP_Active = $354;                              // Bool
        C_Mail_POP_Active = $355;                               // Bool
        C_Mail_IMAP_Active = $356;                              // Bool
        C_Mail_IMAP_IDLEDisable = $43D;                         // Bool         Disable IMAP IDLE
        C_Mail_Control_Active = $357;                           // Bool

	// SMTP service

		// General
		C_Mail_SMTP_General_HostName = $0B;     	// String	Mailserver hostname
		C_Mail_SMTP_General_DeliveryMode = $29;         // Bool		SMTP service delivery mode
			// 0 - Use SMTP relay server
			// 1 - Use DNS lookup
		C_Mail_SMTP_General_RelayMailServer = $26;	// String	SMTP relay server
		C_Mail_SMTP_General_DNSServer = $28;            // String	DNS servers

		// Delivery
		C_Mail_SMTP_Delivery_UseTLSSSL = $87;           // Bool		Use TLS/SSL
		C_Mail_SMTP_Delivery_RetrySMTP = $89;           // Bool		Retry with SMTP when ESMTP failed
		C_Mail_SMTP_Delivery_LimitMsgSize = $56;	// Bool		Enable Max message size
		C_Mail_SMTP_Delivery_MaxMsgSize = $57;          // Int		Max message size (B)
		C_Mail_SMTP_Delivery_MXReconnectFailure = $C7;  // Bool		Deliver message via relay server when direct delivery fails
		C_Mail_SMTP_Delivery_HideIP = $78;		// Bool		Hide IP from received header
                C_Mail_SMTP_Delivery_RDNSLookup = $1C2;         // Bool
		C_Mail_SMTP_Delivery_UndelivAfter = $93;        // Int		Undeliverable after (Minutes)
		C_Mail_SMTP_Delivery_UndelivWarning = $92;      // Int		Undeliverable warning (Minutes)
		C_Mail_SMTP_Delivery_DaemonAlias = $49;		// String	Mailer Daemon report alias
		C_Mail_SMTP_Delivery_DaemonName = $4A;	        // String 	Mailer Daemon report name
		C_Mail_SMTP_Delivery_BadMail = $6A;   		// String	Bad mail address
		C_Mail_SMTP_Delivery_DoNoTruncate = $109;       // Bool		Do not truncate mailer daemon's msgs
		C_Mail_SMTP_Delivery_InfoToAdmin = $8F;         // Bool		Send info to admin
                C_Mail_SMTP_Delivery_UseIncomingQueue = $1C9;   // Bool         Use incoming mail queue
                C_Mail_SMTP_Delivery_IncomingQueueSize = $1CA;  // Int          Size of the queue (# threads)
                C_Mail_SMTP_Delivery_MDAInternal = $1E6;  // Bool               Use MDA queue for internal delivery
                C_Mail_SMTP_Delivery_ReturnPath = $1F7;  // Bool                Add return-path
                C_Mail_SMTP_Delivery_MessageSubmission = $32F; // Bool          Message submission should be checked as in RFC4409 (first port is MTA and second port is MSA)

		// Header/Footer
		C_Mail_SMTP_HeaderFooter_Enable = $3C;		// Bool		Enable Header/Footer

		// Other
		C_Mail_SMTP_Other_Dedupe = $C2;    		// Bool		Dedupe email messages
		C_Mail_SMTP_Other_SearchInLocalDomains = $58;   // Bool		Search for alias in other local domains
		C_Mail_SMTP_Other_HeaderFunctions = $59;        // Bool		Activate message header functions
		C_Mail_SMTP_Other_MaxHopCount = $90;            // Int		Max SMTP hop count
		C_Mail_SMTP_Other_MaxRecipients = $39;   	// Int		Max SMTP server recipients
                C_Mail_SMTP_Other_MaxMTARecipients = $1A5;      // Int		Max SMTP client recipients
		C_Mail_SMTP_Other_LocalDelivery = $FC;          // Bool		Enable remote delivery from local server
		C_Mail_SMTP_Other_ExternalDelivery = $C6;       // Bool		Deliver all messages externally
		C_Mail_SMTP_Other_NoRetryQueue = $BE;		// Bool		Do not queue messages
		C_Mail_SMTP_Other_BounceBackMode = $199;	// Int		Bounce back mode
		C_Mail_SMTP_Other_SMTPPipelining = $D4;         // Bool		Enable SMTP pipelining
                C_Mail_SMTP_Other_SPFSRS = $13E;                // Bool		Enable SRS
                C_Mail_SMTP_Other_SPFSRSKey = $13F;             // String	SRS secret key
                C_Mail_SMTP_Other_SPFSRSNDRVerify = $257;       // Bool
                C_Mail_SMTP_Other_FullMailboxPermanentError = $439; // Bool     Treat full mailbox error as permanent (522 response)
                C_Mail_SMTP_Accept_Invalid_Recipients = $441;       // Bool     If this is enabled and catch all account on primary email is enabled, all invalid recipients are rewritten to catch all account

                C_Mail_SMTP_Other_MailboxSeparator = $16C;      // String	Mailbox separator / extension separator (eg: alias:extension@domain)

                C_Mail_SMTP_Other_IncomingMessageLimits = $285;  // Bool          Should size of incoming mails also be checked

                C_Mail_SMTP_Other_Extensions = $43A;            // String       List of SMTP extensions to alter or disable via "!", separate with semi-colon

	// Security

		// Anti Relaying
		C_Mail_Security_Relay_RelayMode = $83;          // Int		Relay mode
			// 0 - Open relay
			// 1 - Close relay
		C_Mail_Security_Relay_IPList = $84;             // String	List of relayed IP addresses
		C_Mail_Security_Relay_POPSMTP = $8D;    	// Bool		Enable POP before SMTP
		C_Mail_Security_Relay_POPSMTPInt = $8C;		// Int		POP before SMTP interval (Min)
		C_Mail_Security_Relay_POPSMTPGlobal = $1D4;    	// Bool		Enable POP before SMTP global mode
		C_Mail_Security_Relay_RejectLocalUnauth = $B6;  // Bool		Reject if orig's domain is local&unauth

		// Protection
		C_Mail_Security_Protection_DNSBL = $3E;     	// Bool		Enable DNSBL
		C_Mail_Security_Protection_DNSBL_Temporary_Error = $358;     	// Bool		DNSBL returns temporary error
		C_Mail_Security_Protection_CloseDNSBLConn = $BF;// Bool		Close connection for DNSBL sessions
		C_Mail_Security_Protection_RejectrDNS = $30;    // Bool		Reject if sender's IP has no rDNS
		C_Mail_Security_Protection_RejectMX = $8B;      // Bool		Reject if orig's domain has no MX rec
		C_Mail_Security_Protection_SMTPWait = $14C;     // Int		Wait before processing a new conn
		C_Mail_Security_Protection_LocalDomain = $91;   // Bool		Relay only if orig's domain's local
		C_Mail_Security_Protection_DomainIPShield = $A1;// Bool		Use Domain IP shielding
		C_Mail_Security_Protection_RejectSMTPAuthSender = $1C8; // Bool	Reject if SMTP AUTH different from sender
		C_Mail_Security_Protection_HELOEHLO = $36;      // Bool		Require HELO/EHLO
                C_Mail_Security_Protection_IgnoreBlankHeloHost = $16B; // Bool	Ignore Blank Helo Host

		// Intrusion prevention
		C_Mail_Security_Tarpit_Enable = $88;      	// Bool		Enable tarpitting
		C_Mail_Security_Tarpit_EnableSMTP = $88;      	// Bool		Enable SMTP tarpitting	(synonym for C_Mail_Security_Tarpit_Enable)
		C_Mail_Security_Tarpit_EnableIMAPPOP3 =$330;    // Bool         Enable POP3/IMAP tarpitting
                C_Mail_Security_Tarpit_Recipient = $332;        // Bool		Tarpit IP that exceeds unknown users delivery count
		C_Mail_Security_Tarpit_Count = $25;     	// Int		Number of attempts
                C_Mail_Security_Tarpit_RecipientCount = $25;    // Int		Synonym for C_Mail_Security_Tarpit_Count
		C_Mail_Security_Tarpit_Period = $1D;	 	// Int		Tarpitting interval
		C_Mail_Security_Tarpit_RelayTarpit = $B2;       // Bool		Tarpit relay rejected IPs
		C_Mail_Security_Tarpit_RelayTarpitCount = $333; // Int		Count for C_Mail_Security_Tarpit_RelayTarpit

		C_Mail_Security_Tarpit_BlockIP = $C1;           // Bool		Block IPs that establish more than BlockIPValue connections within a minute
		C_Mail_Security_Tarpit_BlockIPValue = $C0;      // Int		Number of limited of connections
                C_Mail_DoNot_Tarpit_IPs = $133;                 // Bool         Do not tarpit IP addresses
                C_Mail_Security_Tarpit_CloseConnection = $14D;  // Bool		Close tarpitted connections
                C_Mail_Security_Tarpit_CrossSession = $14E;     // Bool		Cross session processing
                C_Mail_Security_Tarpit_Msg_Enabled = $1BA;     // Bool		Tarpit message size
                C_Mail_Security_Tarpit_Msg_Value = $1BB;     // Int		Tarpit message size value
                C_Mail_Security_Tarpit_Spam = $1C0;     // Bool  		Tarpit spam
                C_Mail_Security_Tarpit_SpamScore = $1C1;     // Int  		Tarpit spam score (* 100)
                C_Mail_Security_Tarpit_DNSBL = $1C3;     // Bool  		Tarpit DNSBL
                C_Mail_Security_Tarpit_RSET = $1C5;      // Bool                Tarpit RSET
                C_Mail_Security_Tarpit_RSETCount = $1C6; // Int                 Tarpit RSET count
                C_Mail_Security_Tarpit_Login = $299;     // Bool  		Block IPs that blocked an account by exceeding number of failed login attempts
                C_Mail_Security_Tarpit_LoginCount = $331;// Int  		Count for C_Mail_Security_Tarpit_Login
		// Protocols
		C_Mail_Security_Protocols_DenyESMTP = $2A;      // Bool		Deny ESMTP protocol
		C_Mail_Security_Protocols_AllowSMTPAuth = $76;	// Bool		Allow SMTP Auth
  		C_Mail_Security_Protocols_DenyVRFY = $2B;       // Bool		Deny VRFY command
		C_Mail_Security_Protocols_DenyEXPN = $2C;       // Bool		Deny EXPN command
		C_Mail_Security_Protocols_DenyTelnet = $2D;  	// Bool		Deny Telnet access

	// Filtering

		// Content Filters
		C_Mail_Filter_Content_Enable = $77;    		// Bool		Enable Content filters

		// Rules
		C_Mail_Filter_BW_Enable = $8E;                  // Bool		Enable Rules
                C_Mail_Filter_RulesContentXML = $1E5;           // String [D]

                C_Mail_Filter_MaxThreads = $13A;                // Int          Number of filter threads

	// ETRN download
        C_Mail_ETRN_Active = $245;                              // Bool
        C_Mail_ETRN_Schedule = $17E;                            // Schedule	ETRN Schedule

// AS
	// General
	C_AS_General_Enable = $FD;   				// Bool		Enable Spam Engine
        C_AS_General_ProcessingGroup = $19D;                    // String	Policy group
        C_AS_General_AntispamMode = $280;                       // Int          Antispam mode
                // 0 - System
                // 1 - User
                // 2 - Domain


        C_AS_Info_UpdateDate = $146;                            // String	Update date [R]
        C_AS_Info_UpdateVersion = $147;                         // String	Update version [R]
        C_AS_Info_EngineVersion = $148;                         // String	Engine version [R]
        C_AS_Info_UpdateSize = $1DF;                         // Int [R]
        C_AS_Info_BayesWords = $1E0;                         // Int [R]
        C_AS_Info_BayesSpamMessages = $1E1;                         // Int [R]
        C_AS_Info_BayesGenuineMessages = $1E2;                         // Int [R]

	// Challenge Response
        C_AS_Challenge_ProcessingGroup = $19E;                  // String	Policy group

        C_AS_Challenge_ReportsSchedule = $1AF;                  // Schedule

        C_AS_Challenge_ConnectionString = $230;                 // String       Anti spam DB ConnectionString
        C_AS_SpamFolderName = $313;                             // String
        C_AS_UseSpamFolder = $314;                              // Bool

        C_AS_StopList = $038C; // String
        C_AS_SkipCharsets = $038D; // String
        C_AS_SkipCharsetsSpam = $038E; // Bool
        C_AS_IgnoreUnknownWords = $038F; // Bool
        C_AS_SpamFilterRecords = $0390; // String
        C_AS_Graham_Cutoff = $0391; // String
        C_AS_SpamAssassinThreadRegEx = $0392; // Bool
        C_AS_EnableAsianBayesian = $0393; // Bool
        C_AS_AsianBayesTokenLen = $0394; // String
        C_AS_AsianBayesCharacterRange = $0395; // String
        C_AS_VOldWords = $0396; // Int
        C_AS_IndexGenuineAuth = $0397; // Bool
        C_AS_IgnoreFilesLarger = $0398; // Int
        C_AS_Live_IgnoreFilesLarger = $468; // Int                              Greater mails will not be checked by AS Live  (value in KB)
        C_AS_SpamMaxTextBytes = $0399; // Int
        C_AS_IndexDayCount = $039A; // Int
        C_AS_DeleteSpamMailOlder = $039B; // Int
        C_AS_ArchiveIndexedMessages = $039C; // Bool
        C_AS_CharsetSpam = $039D; // Bool
        C_AS_MissingCharset = $039E; // Bool
        C_AS_AddSpamSubject = $039F; // Bool
        C_AS_AddSpamSubjectString = $03A0; // String
        C_AS_BypassLocalIPs = $03A1; // Bool
        C_AS_BypassKeywords = $03A2; // String
        C_AS_BlockKeywords = $03A3; // String
        C_AS_BlockKeywordScore = $03A4; // String
        C_AS_BypassLocalDomains = $03A5; // Bool
        C_AS_SpamOutgoingRules = $03A6; // Int
        C_AS_SpamUseCustomDB = $03A7; // Bool
        C_AS_SpamUseIMAP = $03A8; // Bool
        C_AS_SpamBayesian = $03A9; // Bool
        C_AS_SpamBayesMaxWords = $03AA; // Int
        C_AS_SpamBayesianNoTag = $03AB; // Bool
        C_AS_SpamBypassNonUsers = $03AC; // Bool
        C_AS_SpamBypassGroupware = $03AD; // Bool
        C_AS_SpamBypassIMRoster = $03AE; // Bool
        C_AS_SpamSkipBypassLocalUntrusted = $03AF; // Bool
        C_AS_SpamMaxThreads = $03B0; // Int
        C_AS_SpamAddOutgoing = $03B1; // Bool
        C_AS_SpamApplyUnknown = $03B2; // Bool
        C_AS_SpamHTMLExternalURL = $03B3; // Bool
        C_AS_SpamHTMLNoText = $03B4; // Bool
        C_AS_SpamHTMLScript = $03B5; // Bool
        C_AS_SpamHTMLEqual = $03B6; // Bool
        C_AS_SpamBlankMail = $03B8; // Bool
        C_AS_SpamHTMLOtherFilters = $03B9; // String
        C_AS_SpamReceivedHeader = $03BA; // Bool
        C_AS_SpamReset = $03BB; // Int
        C_AS_SpamRefuse = $03BC; // Int
        C_AS_SpamRefusePath = $03BD; // String
        C_AS_SpamUpdateTime = $03BE; // Int ; Number of seconds from midnight
        C_AS_SpamUpdate = $03BF; // Bool
        C_AS_SpamUpdateDays = $03C0; // Int
        C_AS_SpamUpdateURL = $03C1; // String
        C_AS_SpamUpdateProxy = $03C2; // String
        C_AS_SpamChallenge = $03C3; // Bool
        C_AS_SpamChallengeOldCompatibility = $03C4; // Bool
        C_AS_SpamChallengeMarked = $03C5; // Bool
        C_AS_SpamChallengeUnMarked = $03C6; // Bool
        C_AS_SpamChallengeManual = $03C7; // Bool
        C_AS_SpamChallengeExpires = $03C8; // Int
        C_AS_SpamChallengePerc = $03C9; // Bool
        C_AS_SpamChallengeSpam = $03CA; // Int
        C_AS_SpamChallengeGenuine = $03CB; // Int
        C_AS_SpamChallengeSAPerc = $03CC; // Bool
        C_AS_SpamChallengeSAGenuine = $03CD; // String
        C_AS_SpamChallengeSASpam = $03CE; // String
        C_AS_SpamChallengeURL = $03CF; // String
        C_AS_SpamChallengeMailSender = $03D0; // String
        C_AS_SpamChallengeMailFrom = $03D1; // String
        C_AS_SpamReportMailSender = $03D2; // String
        C_AS_SpamReportMailFrom = $03D3; // String
        C_AS_SpamReportsDebugLevel = $03D4; // Int
        C_AS_SpamReportsLogLevel = $03D5; // Int
        C_AS_SpamChallengeSendOnce = $03D6; // Bool
        C_AS_SpamChallengeFont = $03D7; // String
        C_AS_SpamChallengeFontSize = $03D8; // Int
        C_AS_SpamChallengeLocalDomains = $03D9; // Int
        C_AS_SpamChallengeMoveToSpam = $03DA; // Bool
        C_AS_SpamAssassinEnabled = $03DB; // Bool
        C_AS_SpamAssassinMarked = $03DC; // Bool
        C_AS_SpamAssassinPath = $03DD; // String
        C_AS_SpamAssassinReporting = $03DE; // Bool
        C_AS_SpamAssassinNoCustom = $03DF; // Bool
        C_AS_SpamAssassinMaxScore = $03E0; // Int
        C_AS_SpamAssassinRulesStats = $03E1; // String
        C_AS_CommTouch = $03E2; // Bool
        C_AS_CommTouchServer = $03E3; // String
        C_AS_CommTouchHighScore = $03E4; // String
        C_AS_CommTouchHighestScore = $03E5; // String
        C_AS_CommTouchLowScore = $03E6; // String
        C_AS_CommTouchInfoScore = $41A;// String                                Read only , AS live engine is applied only if score is below this value        
        C_AS_CommTouchForce = $03E7; // Bool
        C_AS_SpamAssassinScore = $03E8; // Bool
        C_AS_SpamAssassinScoreValue = $03E9; // String
        C_AS_SpamAssassinQuarantine = $03EA; // Bool
        C_AS_QuarantineScore = $03EB; // String
        C_AS_SpamAssassinDelete = $03EC; // Bool
        C_AS_DeleteScore = $03ED; // String
        C_AS_SpamGLActive = $03EE; // Bool
        C_AS_SpamGLAdaptive = $45C; // Bool                                     Turns on special adaptive mode for greylisting.  Sender is greylisted after fist message classified as spam is received from him
        C_AS_BypassDistributedDomain = $460; // Bool                            If enabled, Anti-Spam is skipped for non local recipients in distrubuted domain
        C_AS_SpamGLAllow = $03EF; // Int
        C_AS_SpamGLPending = $03F0; // Int
        C_AS_SpamGLAuthorized = $03F1; // Int
        C_AS_SpamGLResponse = $03F2; // String
        C_AS_SpamGLDisconnect = $03F3; // Bool
        C_AS_SpamGLMode = $03F4; // Int
        C_AS_SpamGLOwnerMode = $03F5; // Int
        C_AS_CharsetSpamScore = $03F6; // String
        C_AS_MissingCharsetScore = $03F7; // String
        C_AS_SpamHTMLExternalURLScore = $03F8; // String
        C_AS_SpamHTMLNoTextScore = $03F9; // String
        C_AS_SpamHTMLScriptScore = $03FA; // String
        C_AS_SpamHTMLEqualScore = $03FB; // String
        C_AS_SpamHTMLOtherFiltersScore = $03FD; // String
        C_AS_SpamBlankMailScore = $03FE; // String
        C_AS_SpamReceivedHeaderScore = $03FF; // String
        C_AS_SpamHashActive = $0400; // Bool
        C_AS_SpamHashThreshold = $0401; // Int
        C_AS_SpamHashThresholdExpire = $0402; // Int
        C_AS_SpamHashExpire = $0403; // Int
        C_AS_SpamHashScore = $0404; // String
        C_AS_SpamHashMode = $0405; // Int
        C_AS_SpamNoSenderDomain = $0406; // Bool
        C_AS_SpamNoSenderDomainScore = $0407; // String
        C_AS_SpamHELOIP = $0408; // Bool
        C_AS_SpamHELOIPScore = $0409; // String
        C_AS_SpamRemoteSMTP = $040A; // Bool
        C_AS_SpamRemoteSMTPScore = $040B; // String
        C_AS_SpamRemoteSMTPConnectTimeout = $040C; // Int
        C_AS_SpamBList = $040D; // Bool
        C_AS_SpamWList = $040E; // Bool
        C_AS_SpamBDelete = $040F; // Bool           // Obsolete, only for backward compatibility, use C_AS_BlacklistAction instead
        C_AS_BlacklistAction = $469; // Int         // 0 = Mark As Spam, 1= Delete, 2= Reject

        C_AS_SpamQReports = $0410; // Bool
        C_AS_SpamFReports = $0411; // Bool
        C_AS_SpamQReportsMode = $0412; // Int
        C_AS_SpamLang = $0413; // String
        C_AS_SpamReportsDateFormat = $0415; // String
        C_AS_SpamReportsTimeFormat = $0416; // String

        C_AS_Mailinglist_Quarantine_Disable = $0477; // Bool
        C_AS_Mailinglist_Antispam_Disable = $0478; // Bool

// AV

	// General
	C_AV_General_IntegratedAV = $3D;        		// Bool		Enable Integrated AV scanner
        C_AV_General_ProcessingGroup = $19F;                    // String	Policy group

        C_AV_General_UpdateType = $168;                         // Int		Update Schedule
		// 0 - Disabled
		// 1 - Once at
		// 2 - Every x hours
	C_AV_General_UpdateNotWeekdays = $E9;                   // Int		List of days when server does not check for update
		// bit 1 - Monday ... bit 7 - Sunday
	C_AV_General_UpdateTime = $EB;                          // Int		Update time
		// hours - upper byte
		// minutes - lower byte
	C_AV_General_EveryHour = $C9;                           // Int		Check for update every (Hours)
	C_AV_General_ActiveUpdate = $EA;             		// Bool		Enable Active Update
	C_AV_General_ActiveAddress = $EC;              		// String	Active update email trigger
 	C_AV_General_Proxy_URL = $444;                    // String Proxy URL for connecting to update server, user:pass@server:port

        C_AV_Info_UpdateDate = $149;                            // String	Update date [R]
        C_AV_Info_UpdateSize = $14A;                            // Int		Update size [R]
        C_AV_Info_UpdateVersion = $14B;                         // String	Update version [R]

	// Action
	C_AV_Action_ScanAllParts = $0F;        			// Int		Scan All message parts
	C_AV_Action_Mode = $0E;            			// Int		AV Action mode
		// 1 - Reject
		// 2 - Remove infected attachments
		// 3 - Delete
	C_AV_Action_CleanInfected = $9E;	       		// Bool		Clean infected messages if possible
	C_AV_Action_InfoToAdmin = $47;                  	// Bool		Notification to Admin
	C_AV_Action_InfoToRecipient = $4B;			// Bool		Notification to Recipient
	C_AV_Action_InfoToSender = $60;				// Bool		Notification to Sender
	C_AV_Action_UseQuarantine = $33;                  	// Bool		Quarantine infected messages
	C_AV_Action_QuarantineAddress = $7D;                	// String	Quarantine address/path
	C_AV_Action_QuarantineMode = $D9;                       // Bool		Virus Quarantine mode
		// 0 - Quarantine whole infected messages
		// 1 - Quarantine only infected attachments

        C_AV_Action_MailEnabled = $41B;                         // Bool         Enables AV for mails
        C_AV_Action_MailIMAPEnabled = $41C;                         // Bool         Enables AV for IMAP APPEND
        C_AV_Action_GWEnabled = $41D;                         // Bool         Enables AV for Groupware
        C_AV_Action_GWExtensions = $41E;                         // Bool         Apply extension filters for Groupware
        C_AV_Action_GWExternal = $41F;                         // Bool         Apply external filters for Groupware
        C_AV_Action_FTPEnabled = $420;                         // Bool         Enables AV for FTP
        C_AV_Action_FTPExtensions = $421;                         // Bool         Apply extension filters for FTP
        C_AV_Action_FTPxternal = $422;                         // Bool         Apply external filters for FTP

	// Filters
	C_AV_Filters_BlockFiles = $10B;            		// Bool		Block files with following extensions

	// Misc
	C_AV_Misc_RejectPassProtected = $AC;			// Bool		Reject password protected files
	C_AV_Misc_ApplyAsLast = $BB;              		// Bool		Apply antivirus as the last filter
	C_AV_Misc_Outgoing = $1A3;            		        // Bool		Apply antivirus to outgoing messages
	C_AV_Misc_DisableExternalAV = $9F;                  	// Bool		Disable External AV

	C_AV_MaxThreads = $111;                          	// Int		Max number of concurrent threads
        C_AV_MaxFile = $1D3;                                    // Int          Max message size   in kB

        C_AV_Avast = $135;                                      // Bool		Avast Antivirus usage
        C_AV_Symantec = $136;                                   // Bool		Symantec Antivirus usage
        C_AV_AVG = $137;                                        // Bool		AVG Antivirus usage
        C_AV_Kaspersky = $138;                                  // Bool		Kaspersky Antivirus usage
        C_AV_Kaspersky_Inproc = $428;                           // Bool		Should Kaspersky be used as dll instead of as a service
        C_AV_Kaspersky_TempDeleteOlder = $467;                  // Int    Days, after which kaspersky download temporary directory is cleaned


// Web Service

        C_WebService_Default_HostName = $464;               // String       Used only in directory listing so far. This should be set to point to the virtual host containing the "dir"  folder in root.
        C_WebService_AppMaxThreads = $166;        	        // Int          Number of web service application threads

        C_Proxy_Active = $35D;                                  // Bool
        C_Proxy_Logging = $37E; // Bool
        C_Proxy_Authenticate = $37F; // Bool
        C_Proxy_DayLogging = $380; // Bool
        C_Proxy_DeleteLogs = $381; // Int
        C_Proxy_LoggingS = $382; // String
        C_Proxy_Parent = $383; // String
        C_Proxy_Filter = $384; // String
        C_Proxy_TunnelFilter = $385; // String
        C_Proxy_Users = $386; // String
        C_Proxy_Antivirus = $387; // Bool
        C_Proxy_AntivirusSize = $388; // Int
        C_Proxy_AntivirusPercentage = $389; // Int
        C_Proxy_AntivirusBypass = $38A; // String
        C_Proxy_CommonLog = $38B; // Bool


// SMS Service
        C_SMSService_Active = $1FE;                             // Bool
        C_SMSService_RequireAuth = $211;                        // Bool
        C_SMSService_DeliverContent = $271;                     // Bool
        C_SMSService_ReplyMessage = $272;                       // Bool
        C_SMSService_ProcessingMode = $276;	// Int
		// 0 - All messages
		// 1 - All except selected
		// 3 - Group
		// 5 - Selected domains only
		// 9 - Selected accounts only
        C_SMSService_ProcessingGroup = $277;	// String
        C_SMSService_ExpireMins = $27A;         // Int
        C_SMSService_URL = $289;                // String
        C_SMSService_SenderReplyExpiration = $295; // Int
        C_SMSService_SenderReplyConflict = $296;   // Bool
        C_SMSService_SenderReplyConflictText = $297; // String
        C_SMSService_LocalNumberLen = $365; // Int
        C_SMSService_SubjectPrefix = $43E;  // String                           SMS subject prefix

// ActiveSync
        C_ActiveSync_URL = $28A;                // String
        C_ActiveSync_ProcessingMode = $311;	// Int
		// 0 - All messages
		// 1 - All except selected
		// 3 - Group
		// 5 - Selected domains only
		// 9 - Selected accounts only
        C_ActiveSync_ProcessingGroup = $312;	// String

        C_ActiveSync_DBConnection = $4A9;	// String
        C_ActiveSync_DBUser = $4AA;	// String
        C_ActiveSync_DBPass = $4AB;	// String




// Webmail
        C_Webmail_URL = $28B;                // String
        C_Webmail_TempDeleteOlder = $320;   // Int                        Days, after which webmail temporary directory is cleaned
        C_Install_URL = $31D;               // String
        C_FreeBusy_URL = $359;                  // String
        C_WebAdmin_URL = $35A;                  // String
        C_InternetCalendar_URL = $35B;          // String

// FTP Service

        C_FTPService_Active = $1A6;        	                // Bool         Activate FTP service
        C_FTPService_ProcessingMode = $274;	// Int
		// 0 - All messages
		// 1 - All except selected
		// 3 - Group
		// 5 - Selected domains only
		// 9 - Selected accounts only
        C_FTPService_ProcessingGroup = $275;	// String

// GW

	// General
	C_GW_General_Disable = $B9;                             // Bool		Disable GW service
        C_GW_ProcessingGroup = $1A0;                      	// String
        C_GW_SharedAccountPrefix = $27B;                // String;

        C_GW_SuperUser = $1CB;                                  // String
        C_GW_SuperPass = $1CC;                                  // String
        C_GW_ConnectionString = $235;                           // String       Connection string to GW database
        C_GW_Resources = $327;                                  // String [R]
        C_GW_EnforceUTF8Versit = $353;                          // Bool
        C_GW_CacheCount = $371; // Int
        C_GW_Sender = $372; // String
        C_GW_From = $373; // String
        C_GW_Attachments = $374; // String
        C_GW_AttachmentsMailboxPath = $375; // Bool
        C_GW_LDAPActive = $376; // Bool
        C_GW_LDAPHost = $377; // String
        C_GW_LDAPBase = $378; // String
        C_GW_LDAPUser = $379; // String
        C_GW_LDAPPass = $37A; // String
        C_GW_WebDAVURL = $37B; // String
        C_GW_FreeBusyURL = $37C; // String
        C_GW_ACLNotifications = $37D; // Bool
        C_GW_KeepDeletedItems = $42B; // Bool                 Move deleted items to @@TRASH@@ folder
        C_GW_KeepDeletedItemsExpiration = $42D; // Int       Move deleted items expiration
        C_GW_GAL_DisableUserEditing = $43C; // Bool          Disable users to edit their GAL records
        C_GW_VersionControl = $446;                   // Int       Enable version control for folder types
                // GW_AL_Files = $01;
                // GW_AL_Calendar = $02;
                // GW_AL_Tasks = $04;
                // GW_AL_Journal = $08;
                // GW_AL_Contacts = $10;
                // GW_AL_Notes = $20;
        C_GW_MaxPhotoSize = $457;               // Int  Maximum photo size that is allowed, larger photos will be optimized automatically
        C_GW_ResourcesDisableCalendarFolders = $46a; // Bool Disables resources calendar subfolders
        C_GW_ResourcesDisableNamingByDescription = $4A3; // Bool If set to true, name of calendar folder of group account will not be replaced with resource description

        C_SmartAttach_URLShortenerForTickets = $43B;   // Bool      Enable URL shortener for tickets
        C_SmartAttach_Key = $445;       // String               SmartAttach key

// IM

	// General
	C_IM_General_Disable = $D5;                            	// Bool		Disable IM service
	C_IM_General_Redirectunknown = $D7;         		// Bool		Redirect unknown domain to local domain
	C_IM_General_Anonymous = $DA;  				// Bool		Enable Anonymous server to server communication
	C_IM_General_AccountRegistration = $DB;        		// Bool		Enable Account registration
	C_IM_General_ServerOSReport = $DC;		        // Bool		Enable Server OS report
        C_IM_ProcessingGroup = $1A2;                      	// String
        C_IM_EmailTransportNode = $1E7;                      	// String
        C_IM_SocksServerIP = $21A;                      	// String
        C_IM_SocksServerJID = $32B;                             // String [R]

	// Archiving
	C_IM_Archive_Enable = $C5;				// Bool		Enable IM archive
	C_IM_Archive_DeleteAfter = $C4;                         // Int		Delete IM archive after (Days)
        C_IM_UserHistory = $290;                                // Bool
        C_IM_DeleteUserHistory = $497;                          // Bool  If set to true, IM history of users is deleted after some months. It uses the same settings as "Delete emails older than (days)", but that value is rounded up to months

        // Presence History
        C_IM_Presence_History = $1F9;                           // Bool
        C_IM_Presence_HistoryDelete = $1FA;                     // Int
        C_IM_SubjectPrefix = $43F;                              // String IM subject prefix

// PushServer
        C_PushServer_Active = $1FB;                            // Bool
        C_PushServer_Port = $1FC;                              // Int
        C_PushServer_Heartbeat = $291;                         // Int

// SyncML
        C_SyncML_URL = $242;                                    // String
        C_SyncML_ProcessingMode = $1ED;         // Int
		// 0 - All messages
		// 1 - All except selected
		// 3 - Group
		// 5 - Selected domains only
		// 9 - Selected accounts only
        C_SyncML_ProcessingGroup = $1EF;                      // String

// WebDAV
        C_WebDAV_ProcessingMode = $278;	// Int
		// 0 - All messages
		// 1 - All except selected
		// 3 - Group
		// 5 - Selected domains only
		// 9 - Selected accounts only
        C_WebDAV_ProcessingGroup = $279;	// String
        C_WebDAV_URL = $28C;	// String

// SIP service
                C_System_Services_SIP_Enable = $17F;            // Bool
                C_System_Services_SIP_Port = $180;              // Int
                C_System_Services_SIP_DebugFile = $189;         // String
                C_System_Services_SIP_NoRecordRoute = $181;     // Bool
                C_System_Services_SIP_LocalNet = $182;          // String
                C_System_Services_SIP_RemoteAccessHost = $183;  // String
                C_System_Services_SIP_LocalAccessHost = $184;  // String
                C_System_Services_SIP_OtherProxy = $185;  // String
                C_System_Services_SIP_UseOtherProxy = $186;  // Bool
                C_System_Services_SIP_DisableAnonymousAccess = $187;  // Bool
                C_System_Services_SIP_DisableRegistrar = $188;  // Bool
                C_System_Services_SIP_DisableSymmetricResponseRouting = $198;  // Bool
                C_System_Services_SIP_Calls = $192;  // Bool
                C_System_Services_SIP_CallsFile = $193;  // String
                C_System_Services_SIP_UserCalls = $1D5;  // Bool
                C_System_Services_SIP_ENUM = $1DC; // Bool
                C_System_Services_SIP_Services = $364; // Bool
                C_System_Services_SIP_SDPProxy = $18C;  // Bool
                C_System_Services_SIP_SDPRemoteAccessHost = $18D;  // String
                C_System_Services_SIP_Mode = $18E;  // Int
                C_System_Services_SIP_RTPProxy = $18F;  // Bool
                C_System_Services_SIP_RTPStart = $190;  // Int
                C_System_Services_SIP_RTPMax = $191;  // Int
                C_System_Services_SIP_MaxCalls = $194;  // Int
                C_System_Services_SIP_DNSEnabled = $195; // Bool
                C_System_Services_SIP_AccessGroup = $1A1;                      // String
                C_System_Services_SIP_SSLPort = $1B3;                      // Int
                C_System_Services_SIP_List = $1B4;                      // String
                C_System_Services_SIP_Grant = $1B5;                      // Bool
                C_System_Services_SIP_ContactExpires = $1FD;            // Int
                C_System_Services_SIP_CallerAlias =  $287;              // String
                C_System_Services_SIP_CallerName =  $288;               // String
                C_System_Services_SIP_RTCP = $28D;                      // Bool
                C_System_Services_SIP_RTPDump = $28E;                      // Bool
                C_System_Services_SIP_RTPDumpPath = $28F;                      // String
                C_System_Services_SIP_RTPDumpFlags = $414; // Int ; bit flags (0x01 - Wave, 0x02 - NoDeleteDump, 0x04 - NoMerge)
                C_System_Services_SIP_BasicAuth = $438;  // Bool
                C_System_Services_SIP_LocalHostDomain = $442; // String





// Schedule 

  S_ForceDial = $00;           					// Bool
  S_WeekDays_Mo = $02;           				// Bool
  S_WeekDays_Tu = $03;           				// Bool
  S_WeekDays_We = $04;           				// Bool
  S_WeekDays_Th = $05;           				// Bool
  S_WeekDays_Fr = $06;           				// Bool
  S_WeekDays_Sa = $07;           				// Bool
  S_WeekDays_Su = $08;           				// Bool
  S_ScheduleType = $09;          				// Int (stEvery, stOnce)
  S_ScheduleWhen = $260;          				// Int (stWeekdays, stDaysInMonth,stDisabled)
  S_DaysInMonth = $261;          				// String
  S_OnceAt = $0A;                				// Int
  S_Every = $0B;                 				// Int
  S_WholeDay = $0C;              				// Bool
  S_BetweenFrom = $0D;           				// Int
  S_BetweenTo = $0E;             				// Int

  S_Backup = $0F;                				// String

// Statistics

  ST_Time = $00;                    			        // Int  	Unix time
  ST_ServerOut = $01;                   			// Int 		kB
  ST_ServerIn = $02;                    			// Int 		kB
  ST_ClientOut = $03;                   			// Int 		kB
  ST_ClientIn = $04;                    			// Int 		kB
  ST_Server = $05;                      			// Int
  ST_ServerPeak = $06;                      			// Int
  ST_Client = $07;                      			// Int
  ST_ClientPeak = $08;                      			// Int
  ST_ServerConns = $0B;                      			// Int
  ST_PeakWorkingSetSize = $17;               			// Int
  ST_PageFileUsage = $18;               			// Int
  ST_WorkingSetSize = $19;               			// Int
  ST_RunningTime = $1A;                    			// Int

  ST_SMTP_MessageOut = $0C;                      		// Int
  ST_SMTP_MessageIn = $0D;                     			// Int
  ST_SMTP_MessageFailed = $0E;                      		// Int

  ST_SMTP_FailedGL = $0F;                      			// Int
  ST_SMTP_FailedVirus = $10;                      		// Int
  ST_SMTP_FailedCF = $11;                      			// Int
  ST_SMTP_FailedStaticFilter = $12;                      	// Int
  ST_SMTP_FailedFilter = $13;                      		// Int
  ST_SMTP_FailedRBL = $14;                      		// Int
  ST_SMTP_FailedTarpit = $15;                      		// Int
  ST_SMTP_FailedSpam = $16;                      		// Int
  ST_SMTP_FailedSpamQuarantine = $1B;                      		// Int
  ST_SMTP_FailedSpamRefused = $1C;                      		// Int
  ST_SMTP_FailedSA = $1D;                      		// Int
  ST_SMTP_FailedCTBulk = $1E;                      		// Int
  ST_SMTP_FailedCTSpam = $1F;                      		// Int

  ST_SIP_PacketsIn = $0C;                      		// Int
  ST_SIP_PacketsOut = $0D;                     			// Int
  ST_SIP_RTPPacketsIn = $0E;                      		// Int
  ST_SIP_RTPPacketsOut = $0F;                      			// Int

// Validation
  V_Account_PassPolicy = AnsiString('passpolicy');

Implementation
// Last Used ID: $4AB
End.
