Unit toolhelp;

Interface

Procedure Help(Section: AnsiString = ''; About: Boolean = True);

Implementation

Uses StringUnit, toolunit, SysUtils{$IFDEF UNICODE}, AnsiStrings{$ENDIF UNICODE};

Type
  THelpItem = Record
    Section: AnsiString;
    Value: AnsiString;
  End;

Const
  H_Version = AnsiString('3.8');

  H_Title = AnsiString('tool v' + H_Version + ' for IceWarp Server' + cCRLF);

  H_About = AnsiString(
    H_Title +
    'Copyright (c) 1999-2012 IceWarp Ltd. All rights reserved.' + cCRLF +
    'E-mail: info@icewarp.com' + cCRLF +
    '' + cCRLF);

  H_Usage = AnsiString(
    'Usage: tool [options] <command> <object> <parameters>' + cCRLF +
    '' + cCRLF);

  H_HelpFooter = AnsiString(
    'Tip:' + cCRLF +
    '  Run tool --tutorial to display quick tutorial.' + cCRLF +
    '  See files in ./api directory and ./api/delphi/apiconst.pas'+cCRLF+
    '  for more information.' + cCRLF +
    '' + cCRLF);

  H_CommandList = AnsiString(
    'Commands (help: tool <command>):' + cCRLF +
    'create/new/add <object>     - Creates new object' + cCRLF +
    'delete <object>             - Deletes an object' + cCRLF +
    'modify/set <object>         - Modifies object variables' + cCRLF +
    'display/get/list <object>   - Displays object variables' + cCRLF +
    'check/validate <object>     - Validates object data' + cCRLF +
    'export <object>             - Exports object variables in CSV format' + cCRLF +
    'import <object> <filename>  - Imports objects in CSV format from file' + cCRLF +
    'upgrade <version> [noforce] - Calls upgrade functions from previous version' + cCRLF +
    'search <keyword>            - Search API for string' + cCRLF +
    'log <thread> <svc> <whoe> <msg> - Calls log function' + cCRLF +
    '' + cCRLF);

  H_ObjectList = AnsiString(
    'Objects:' + cCRLF +
    'system         - <variables>' + cCRLF +
    'domain         - <domain> <variables>' + cCRLF +
    'account        - <account> <variables>' + cCRLF +
    'remoteaccount  - <account> <variables>' + cCRLF +
    'service        - <service> <variables>' + cCRLF +
    'userstatistics - <fromdate> <todate> <filterstring>' + cCRLF +
    'tables         - <service> <connectionstring>' + cCRLF +
    'backup         - <filename>' + cCRLF +
    'storage        - <todb>' + cCRLF +
    '' + cCRLF);

  H_Options = AnsiString(
    'Options:' + cCRLF +
    '-m (--template=) name - Apply object template' + cCRLF +
    '-r (--remote=) info   - Connects to a remote server (help: tool remote)' + cCRLF +
    '-p (--path=)   dir    - Path to the server directory' + cCRLF +
    '-f (--filter=) value  - Filter for account display (help: tool filter)' + cCRLF +
    '-q (--quiet)          - Runs in quiet mode' + cCRLF +
    '-h (--help / -?)      - This help' + cCRLF +
    '-t (--tutorial)       - Show quick tutorial' + cCRLF +
    '-v (--version)        - Display version info' + cCRLF +
    '' + cCRLF);

Const
  ContentCount = 13;

Var
  HelpContent: Array [$00..ContentCount - $01] Of THelpItem = (

  // Tutorial
  (Section: 'tutorial';
  Value:
    'Quick tool tutorial:' + cCRLF +
    '####################' + cCRLF +cCRLF +
    '# Create a new domain doe.com:' + cCRLF +
    '------------------------------' + cCRLF +
    '  tool create domain doe.com d_description "Test domain"' + cCRLF + cCRLF +cCRLF +
    '# Create accounts using name, pass and comment:' + cCRLF +
    '-----------------------------------------------' + cCRLF +
    '  tool create account john@doe.com u_name "John Doe" u_password "john_pass" u_comment "John''s first test account"' + cCRLF +cCRLF +
    '  tool create account alex@doe.com u_name "Alex Doe" u_password "alex_pass" u_comment "Second test account"' + cCRLF +cCRLF +
    '  tool create account tom@doe.com u_name "Thomas Doe" u_password "tom_pass" u_comment "Third test account. Tom''s first mail account."' + cCRLF +cCRLF +cCRLF +
    '# Display comments of all doe.com accounts:' + cCRLF +
    '-------------------------------------------' + cCRLF +
    '  tool display account "*@doe.com" domain u_comment' + cCRLF +cCRLF +cCRLF +
    '# Export all accounts of doe.com where the comment contains word "first" to '+ cCRLF+
    '  file doe_com.csv using --filter option:' + cCRLF +
    '-----------------------------------------' + cCRLF +
    '  tool -filter="u_comment like ''%first%''" export account "*@doe.com" u_name u_password u_comment > doe_com_custom.csv' + cCRLF +cCRLF +cCRLF +
    '# Export all accounts of doe.com to csv file (base64 encoded)' + cCRLF +
    '-------------------------------------------------------------' + cCRLF +
    '  tool export account "*@doe.com" u_backup > doe_com.csv' + cCRLF +cCRLF +cCRLF +
    '# Display comments of all doe.com accounts:' + cCRLF +
    '-------------------------------------------' + cCRLF +
    '  tool display account "*@doe.com" domain u_comment' + cCRLF +cCRLF +cCRLF +
    '# Delete all domain accounts:' + cCRLF +
    '-----------------------------' + cCRLF +
    '  tool delete account "*@doe.com"' + cCRLF +cCRLF +cCRLF +
    '# Import accounts from a file:' + cCRLF +
    '------------------------------' + cCRLF +
    '  tool import account "doe_com.cvs" u_name u_password u_comment' + cCRLF +cCRLF +cCRLF +
    '# Modify comment of all accounts @doe.com:' + cCRLF +
    '------------------------------------------' + cCRLF +
    '  tool modify account "*@doe.com" u_comment "Modified comment"' + cCRLF + cCRLF +cCRLF +
    '# Delete all account of doe.com domain and delete doe.com domain:' + cCRLF +
    '-----------------------------------------------------------------' + cCRLF +
    '  tool delete account "*@doe.com"' + cCRLF +
    '  tool delete domain "doe.com"' + cCRLF + cCRLF +cCRLF +
    '' + cCRLF +
    'More examples:' + cCRLF + cCRLF+
    '# Show some system variables:' + cCRLF +
    '-----------------------------' + cCRLF +
    '  tool display system c_system_services_smtp_port c_version c_configpath' + cCRLF + cCRLF+cCRLF+
    '# Change a system variable:' + cCRLF +
    '-----------------------------' + cCRLF +
    '  tool modify system c_as_general_enable 1' + cCRLF +cCRLF+cCRLF+
    '# Display some information' + cCRLF +
    '---------------------------' + cCRLF +
    '  tool display service smtp st_runningtime st_serverout st_server' + cCRLF +cCRLF+
    '  tool display userstatistics 2004/10/01 2004/10/31 "*"' + cCRLF +cCRLF+
    '  tool display remoteaccount "*@icewarp.com" ra_server ra_username' + cCRLF +cCRLF+cCRLF+
    '# Create remote account' + cCRLF +
    '-----------------------' + cCRLF +
    '  tool create remoteaccount @doe.com ra_server server.name.com ra_username user_name' + cCRLF +cCRLF+cCRLF+
    '# Upgrade database from version 8.0.3 to current:' + cCRLF +
    '-------------------------------------------------' + cCRLF +
    '  tool upgrade 8.0.3' + cCRLF +
    '  note: backup database before calling upgrade function' + cCRLF +cCRLF+cCRLF+
    '# Display all domains on remote server and their description.' + cCRLF +
    '-----------------------------------------------------------' + cCRLF +
    '  tool -remote="admin,adminspass,remote.server.com:32000" display domain "*" D_Description' + cCRLF +cCRLF+cCRLF+
    '# Display variables of an object' + cCRLF +
    '--------------------------------' + cCRLF +
    '  tool search domain' + cCRLF +cCRLF+cCRLF+
    '# Create/drop tables for domains and accounts in sqlite DB '+cCRLF+
    '  and force server to use this DB' + cCRLF +
    '---------------------------------' + cCRLF +
    ' tool create tables 0 D:\storage.db;;;;;3' + cCRLF +cCRLF+
    ' tool delete tables 0 D:\storage.db;;;;;3' + cCRLF +cCRLF+cCRLF+
    '# Create/drop tables for groupware in sqlite DB'+cCRLF+
    '  and force server to use this DB' + cCRLF +
    '---------------------------------' + cCRLF +
    ' tool create tables 2 D:\gw.db;;;;;3' + cCRLF +cCRLF+
    ' tool delete tables 2 D:\gw.db;;;;;3' + cCRLF +cCRLF+cCRLF+
    '# Convert account storage to database' + cCRLF +
    '-------------------------------------' + cCRLF +
    ' tool set storage 1' + cCRLF +cCRLF+cCRLF+
    '# Convert account storage to filesystem' + cCRLF +
    '---------------------------------------' + cCRLF +
    ' tool set storage 0' + cCRLF +cCRLF+cCRLF+
    '# Backup settings (the same action as "File/Backup Settings" '+cCRLF+
    '  in Administration Console)' + cCRLF +
    '----------------------------' + cCRLF +
    ' tool export backup c:\temp\mybackupfile.zip' + cCRLF +cCRLF+cCRLF+
    '# Restore settings (the same action as "File/Restore Settings" '+cCRLF+
    '  in Administration Console)' + cCRLF +
    '----------------------------' + cCRLF +
    ' tool import backup c:\temp\mybackupfile.zip' + cCRLF +cCRLF+cCRLF+
    '' + cCRLF),

  // remote
  (Section: 'remote';
  Value:
    'Usage: tool --remote=<info> [options] <command> <object> <parameters>' + cCRLF +
    '' + cCRLF +
    'Info:' + cCRLF +
    '  info=<user>,<pass>,<server:port>[,"ssl"]' + cCRLF +
    '' + cCRLF +
    '  user        - admin username' + cCRLF +
    '  pass        - admin password' + cCRLF +
    '  server:port - remote server and port' + cCRLF +
    '' + cCRLF),

  // filter
  (Section: 'filter';
  Value:
    'Usage: tool --filter=<conditions> [options] <command> <object> <parameters>' + cCRLF +
    '' + cCRLF +
    'Conditions:' + cCRLF +
    '  IceWarp is using SQL like syntax:' + cCRLF +
    '  --filter="<variable> like "%aaa%" AND <variable> = ''1''"' + cCRLF +
    '' + cCRLF +
    'Note 1:' + cCRLF +
    '________' + cCRLF +

    '  There is a difference regarding how filter variables can be used, depending' + cCRLF +
    '  if your accounts are set to file-system or to database storage:' + cCRLF + cCRLF+
    '  - If using file system, it''s possible to use all API variables' + cCRLF +
    '    (see merak/api/apiconst.pas file).' + cCRLF +cCRLF+
    '  - If your accounts are stored on a database, you cannot use all '+cCRLF+
    '    the API variables shown in apiconst.pas. Might be necessary to ' + cCRLF+
    '    do a direct query/insert in the database.'+cCRLF+ cCRLF+
    'Note 2:' + cCRLF +
    '________' + cCRLF +
    '  You can not use filter for domain variables, only for user variables.' + cCRLF+ cCRLF+
    'Note 3:' + cCRLF +
    '________' + cCRLF +
    '  If you are interested in changing values for multiple accounts at once,'+ cCRLF+
    '  please look at the "group templates" in Console/Management/Group/Options.' + cCRLF),







  // version
  (Section: 'version';
  Value:
    'Version: ' + H_Version + cCRLF),

  // create
  (Section: 'create';
  Value:
    'Usage: tool [options] create <object> <parameters>' + cCRLF +
    '' + cCRLF +
    'Description:' + cCRLF +
    ' Create a new object using specified values of parameters (if set).' + cCRLF +
    ' Available options: -r/-p, -f, -q' + cCRLF +
    '' + cCRLF +
    'Object:' + cCRLF +
    ' system         - system parametrs' + cCRLF +
    ' domain         - domain properties' + cCRLF +
    ' account        - email account properties' + cCRLF +
    ' remoteaccount  - Remote account properties' + cCRLF +
    ' tables         - service connectionstring' + cCRLF +
    ' backup         - filename' + cCRLF +
    '' + cCRLF +
    'Parameters <name> [<variable 1>=<value 1> <variable 2>=<value 2> ... <parameter N>=<value N>]' + cCRLF +
    ' Name: Name of object (ie some_domain.com for domain or "doe@some_domain.com").' + cCRLF +
    '       For tables, Name  is id number of database' + cCRLF+
    '         (0 - Storage, 1- Logs, 2- Groupware, 3- AntiSpam).' + cCRLF +
    ' See "tool search <object>" for more information.' + cCRLF+
    ' Note: "create tables" also immediately forces server to use this tables' + cCRLF),

  // modify
  (Section: 'modify';
  Value:
    'Usage: tool [options] modify <object> <parameters>' + cCRLF +
    '' + cCRLF +
    'Description:' + cCRLF +
    ' Modifies some variables of object specified by <object specification> parameters.' + cCRLF +
    ' Available options: -r/-p, -f, -q' + cCRLF +
    '' + cCRLF +
    'Objects:' + cCRLF +
    ' system         - system parametrs' + cCRLF +
    ' domain         - domain properties' + cCRLF +
    ' account        - email account properties' + cCRLF +
    ' remoteaccount  - Remote account properties' + cCRLF +
    ' storage        - Convert storage to database/filesystem' + cCRLF +
    '' + cCRLF +
    'Parameters: <object scpecification> [<variable 1>=<value 1> <variable 2>=<value 2> ... <parameter N>=<value N>]' + cCRLF +
    ' Object specification: Object mask (ie. for account "doe@some_domain.com").' + cCRLF +
    ' See "tool search <object>" for more information.' + cCRLF +
    ' Tip: "tool set storage 1" converts account storage to database.' + cCRLF+
    '      "tool set storage 0" converts account storage to filesystem.' + cCRLF

    ),

  // delete
  (Section: 'delete';
  Value:
    'Usage: tool [options] delete <object>' + cCRLF +
    '' + cCRLF +
    'Description:' + cCRLF +
    ' Deletes an object specified by <object specification> parameter.' + cCRLF +
    ' Available options: -r/-p, -f, -q' + cCRLF +
    '' + cCRLF +
    'Object:' + cCRLF +
    ' system         - system parametrs' + cCRLF +
    ' domain         - domain properties' + cCRLF +
    ' account        - email account properties' + cCRLF +
    ' remoteaccount  - Remote account properties' + cCRLF +
    ' tables         - service connectionstring' + cCRLF+
    ''+cCRLF+
    ' See help for "create" for more information on <object specification>.' +cCRLF),

  // display
  (Section: 'display';
  Value:
    'Usage: tool [options] display <object> <parameters>' + cCRLF +
    '' + cCRLF +
    'Description:' + cCRLF +
    ' Displays some variables of object specified by <object specification> parameter.' + cCRLF +
    ' Available options: -r/-p, -f, -q' + cCRLF +
    '' + cCRLF +
    'Object:' + cCRLF +
    ' system         - system parametrs' + cCRLF +
    ' domain         - domain properties' + cCRLF +
    ' account        - email account properties' + cCRLF +
    ' remoteaccount  - Remote account properties' + cCRLF +
    ' service        - service properties' + cCRLF +
    ' userstatistics - fromdate todate filterstring' + cCRLF +
    '' + cCRLF +
    'Parameters: <object_scpecification> [<variable 1> <variable 2> ... <variable N>]' + cCRLF +
    ' Object specification: Object mask (ie. for account "doe@some_domain.com").' + cCRLF +
    ' Optional: See "tool search <object>" for more information.' + cCRLF),

  // check
  (Section: 'check';
  Value:
    'Usage: tool [options] check <object> <type>' + cCRLF +
    '' + cCRLF +
    'Description:' + cCRLF +
    ' Display objects that fail the validation function for <type>.' + cCRLF +
    ' Available options: -r/-p, -f, -q' + cCRLF +
    '' + cCRLF +
    'Object:' + cCRLF +
    ' account        - email account properties' + cCRLF +
    '' + cCRLF +
    'Type: passpolicy' + cCRLF +
    ' Tip: "tool check account "*@*" passpolicy"  ' + cCRLF),

  // search
  (Section: 'search';
  Value:
    'Usage: tool [options] search <keyword>' + cCRLF +
    '' + cCRLF +
    'Description:' + cCRLF +
    ' Search API for a keyword.' + cCRLF +
    '' + cCRLF +
    'Keyword: string you are looking for. ie: ''account'', ''U_comment''' + cCRLF),

  // upgrade
  (Section: 'upgrade';
  Value:
    'Usage: tool [options] upgrade <old_version>' + cCRLF +
    '' + cCRLF +
    'Description:' + cCRLF +
    ' Upgrade procedural functions from old version to current version.' + cCRLF +
    ' Not usable for downgrading.' + cCRLF +
    '' + cCRLF +
    'Old_version: numeric specification of previous version. ie: 8.0.3' + cCRLF),

  // export / import
  (Section: 'export';
  Value:
    'Usage: tool [options] export <object> <parameters>' + cCRLF +
    '' + cCRLF +
    'Description:' + cCRLF +
    ' Export variables of objects specified by <object_spec> to standard output.' + cCRLF +
    ' Available options: -r/-p, -f, -q' + cCRLF +
    '' + cCRLF +
    'Object:' + cCRLF +
    ' domain         - domain properties' + cCRLF +
    ' account        - email account properties' + cCRLF +
    ' remoteaccount  - remote account properties' + cCRLF +
    ' backup         - filename' + cCRLF +
    '' + cCRLF +
    'Parameters: <object scpecification> [<variable 1> <variable 2> ... <variable N>]' + cCRLF +
    ' Object specification: Object mask (ie. for account "doe@some_domain.com").' + cCRLF +
    ' Optional: variables name separated by spaces. See "tool search <object>" for more information.' + cCRLF +
    '' + cCRLF +
    ' Tip: variable u_backup (d_backup) provides base64 encoded content of each object.' + cCRLF),

  (Section: 'import';
  Value:
    'Usage: tool [options] import <object> <parameters>' + cCRLF +
    '' + cCRLF +
    'Description:' + cCRLF +
    ' Import objects from a file. Variables have to be in same order as in input file contains.' + cCRLF +
    ' Available options: -r/-p, -f, -q' + cCRLF +
    '' + cCRLF +
    'Object:' + cCRLF +
    ' domain         - domain properties' + cCRLF +
    ' account        - email account properties' + cCRLF +
    ' remoteaccount  - remote account properties' + cCRLF +
    ' backup         - filename [password]' + cCRLF +
    '' + cCRLF +
    'Parameters: [<variable 1> <variable 2> ... <variable N>]' + cCRLF +
    '' + cCRLF +
    ' Tip: Use the same variable list as for the export command' + cCRLF)
  );

Function ContentHelp(Section: AnsiString): Boolean;
Var
  FI: Longint;
Begin
  Result := False;

  Section := LowerCase(Section);
  For FI := $00 To Length(HelpContent) - $01 Do
    If HelpContent[FI].Section = Section Then
    Begin
      Write(HelpContent[FI].Value);
      Result := True;
      Break;
    End;
End;

Procedure Help(Section: AnsiString = ''; About: Boolean = True);
Var
  Usage: Boolean;
Begin
  // About
  If About Then Write(H_About);

  Usage := True;

  // Content help
  If Length(Section) > $00 Then Usage := Not ContentHelp(Section);

  // Usage
  If Usage Then
  Begin
    Write(H_CommandList);

    Write(H_ObjectList);

    Write(H_Options);

    Write(H_HelpFooter)
  End

End;

End.

