Unit toolunit;

Interface

Uses
  SysUtils,
{$IFNDEF TOOL_ACTIVEX}
  icewarpservercom,
{$ENDIF}
  SystemUnit, StringUnit, MimeUnit;

Const
  cComment = AnsiChar(';');
  cProto = AnsiString('://');
  cDisplaySep = AnsiString(': ');

  R_ERROR_API_INITIALIZATION = 1;
  R_ERROR_PARAMS = 2;
  R_ERROR_API_FAILURE = 3;
  R_ERROR_ACCOUNT_CREATE_USER_EXISTS = 4;
  R_ERROR_ACCOUNT_CREATE_PASSWORD_POLICY = 5;
  R_ERROR_ENV_VARS = 6;
  R_ERROR_USER_SWITCH = 7;


Type
  TProcessItem = (piModify, piDisplay, piExport, piDelete, piImport, piSearch, piFile, piUpgrade, piCreate, piValidate, piLog);

{$IFDEF TOOL_ACTIVEX}
  TXAPIObject = OleVariant;
  TXDomainObject = OleVariant;
  TXRemoteAccountObject = OleVariant;
  TXAccountObject = OleVariant;
  TXTokenObject = OleVariant;
  TXServiceObject = OleVariant;

  TXObject = OleVariant;
  TXVariant = OleVariant;

{$ELSE}
  TXAPIObject = TAPIObject;
  TXDomainObject = TDomainObject;
  TXRemoteAccountObject = TRemoteAccountObject;
  TXAccountObject = TAccountObject;
  TXTokenObject = TTokenObject;
  TXServiceObject = TStatisticsObject;

  TXObject = TObject;
  TXVariant = Longint;

  IDispatch = Pointer;

Const
  Unassigned = Nil;
{$ENDIF}

Function CreateObject(Obj: AnsiString): OleVariant;

Procedure Unset(Var Obj: TXObject);

Procedure APIInit;

Procedure APIDone;

Procedure CreateRPC(RPC: AnsiString);

Function GetCommaString(S: AnsiString; Index: Longint): AnsiString;

Function GetNextParam(Var Index: Longint; Var FParam, FValue: AnsiString; NoValue: Boolean = False): Boolean;

Function FindParam(Var Index: Longint; const Param: AnsiString; Var Value: AnsiString): Boolean;

Function GetProcessMode(Command: AnsiString): TProcessItem;

Function CommaString(Str: AnsiString): AnsiString;

Procedure ParseParameters;

Function ParamStr(Index: Longint): AnsiString;

Function ParamCount: Longint;

Function ParseBatchLine(Line: AnsiString): Boolean;

Procedure Writeln(Str: AnsiString = ''; Force: Boolean = False);

Function IsStringMask(const S: AnsiString): Boolean;

Var
  FAPI: TXAPIObject;
  FToken: TXTokenObject;
  TokenHandle: Longint = $00;
  QuietMode: Boolean = False;
  ParamOptions: Longint = $00;
  InitPath: AnsiString = '';
  Filter: AnsiString = '';
  Template: AnsiString = '';

Const
  // Commmands
  CCREATE = AnsiString('CREATE');
  CMODIFY = AnsiString('MODIFY');
  CSET = AnsiString('SET');
  CNEW = AnsiString('NEW');
  CADD = AnsiString('ADD');
  CDELETE = AnsiString('DELETE');
  CDISPLAY = AnsiString('DISPLAY');
  CLIST = AnsiString('LIST');
  CGET = AnsiString('GET');
  CFILE = AnsiString('FILE');
  CEXPORT = AnsiString('EXPORT');
  CIMPORT = AnsiString('IMPORT');
  CUPGRADE = AnsiString('UPGRADE');
  CSEARCH = AnsiString('SEARCH');
  CCHECK = AnsiString('CHECK');
  CVALIDATE = AnsiString('VALIDATE');
  CLOG = AnsiString('LOG');

  // Parameters
  CACCOUNT = AnsiString('ACCOUNT');
  CREMOTEACCOUNT = AnsiString('REMOTEACCOUNT');
  CDOMAIN = AnsiString('DOMAIN');
  CTABLES = AnsiString('TABLES');
  CSYSTEM = AnsiString('SYSTEM');
  CUSERSTATISTICS = AnsiString('USERSTATISTICS');
  CBATCH = AnsiString('BATCH');
  CSERVICE = AnsiString('SERVICE');
  CBACKUP = AnsiString('BACKUP');
  CSTORAGE = AnsiString('STORAGE');

  // Options
  CQUIET = AnsiString('QUIET');
  CQ = AnsiChar('Q');

  CHELP = AnsiString('HELP');
  CH = AnsiChar('H');

  CRPC = AnsiString('RPC');
  CREMOTE = AnsiString('REMOTE');
  CR = AnsiChar('R');

  CPATH = AnsiString('PATH');
  CP = AnsiChar('P');

  CFILTER = AnsiString('FILTER');
  CF = AnsiChar('F');

  CTEMPLATE = AnsiString('TEMPLATE');
  CM = AnsiChar('M');

  CTUTORIAL = AnsiString('TUTORIAL');
  CT = AnsiChar('T');

  CVERSION = AnsiString('VERSION');
  CV = AnsiChar('V');

  CouldNotInitAPI = AnsiString('Could not initialize the API');
  CouldNotInitRemoteAPI = AnsiString('Could not connect or authenticate to the remote server');
  ElevationRequired = AnsiString('Access Denied. Administrator permissions are needed to use the selected options. Use an administrator command prompt to complete these tasks.');
  EnvVarNotSet = AnsiString('ERROR: Environment variable %s is not set');
  ErrCannotFindUser = AnsiString('ERROR: Cannot find user %s');
  ErrCannotSwitchUser = AnsiString('ERROR: Cannot switch to user %s');

  SettingsUpdated = AnsiString('Settings updated.');
  SettingsProblem = AnsiString('Settings save problem.');

  BackupFinished = AnsiString('Backup to %s finished.');
  BackupProblem = AnsiString('Backup problem.');
  RestoreFinished = AnsiString('Restore from %s finished.');
  RestoreProblem = AnsiString('Restore problem');

  DomainDeleted = AnsiString('Domain %s deleted.');
  DomainNotFound = AnsiString('Domain %s not found.');
  DomainCreated = AnsiString('Domain %s created.');
  DomainUpdated = AnsiString('Domain %s updated.');
  DomainExists = AnsiString('Domain %s already exists.');
  DomainProblem = AnsiString('Domain %s save problem.');

  AccountDeleted = AnsiString('Account %s deleted.');
  AccountNotFound = AnsiString('Account %s not found.');
  AccountCreated = AnsiString('Account %s created.');
  AccountUpdated = AnsiString('Account %s updated.');
  AccountExists = AnsiString('Account %s already exists.');
  AccountProblem = AnsiString('Account %s save problem.');

  StorageOk = AnsiString('Storage conversion finished.');
  StorageFailed = AnsiString('Storage conversion problem.');

  ImportProblem = AnsiString('Import failed. Can not open file %s.');

  PasswordPolicyViolation = AnsiString('Password policy violation.');

  cUALIAS = AnsiString('u_alias');
  cUALIASLIKE = AnsiString('( (u_alias like ''%0:s'') or (u_alias like ''%0:s;%%'') )');

Type
  TParameters = Array Of AnsiString;

Var
  Parameters: TParameters = Nil;

Implementation

Uses
{$IFDEF MSWINDOWS}
  Windows, ActiveX, ComObj,
{$ENDIF}
  Variants{$IFDEF UNICODE}, AnsiStrings{$ENDIF UNICODE};

{$IFNDEF TOOL_ACTIVEX}
Function CoInitializeEx(Reserved: Pointer; Val: Longint): Longint;
Begin
  Result := $00;
End;

Function CreateObject(Obj: AnsiString): OleVariant;
Begin
  Result := Longint(CreateClassObject(Obj));
End;

Procedure Unset(Var Obj: TXObject);
Begin
  Obj.Free;
End;

{$ELSE}
Function CreateObject(Obj: AnsiString): OleVariant;
Begin
  CoInitializeEx(Nil, 0);

  Result := CreateOleObject(String(Obj));
End;

Procedure Unset(Var Obj: TXObject);
Begin
  Obj := Unassigned;
End;
{$ENDIF}

Procedure APIInit;
Var
  FTokenError: Boolean;
Begin
  // Global API instance
  Try
    FAPI := Unassigned;
    FAPI := TXAPIObject(TXVariant(CreateObject('IceWarpServer.APIObject')));
    FAPI.TokenHandle := TokenHandle;

    // Init path
    if Length(InitPath) > $00 Then FAPI.Init(InitPath);
  Except
  End;

  // Token error
  FTokenError := ((IDispatch(FToken) <> Nil) And (FToken.Counter = $00));

  // Check if instance created and if token set whether it has been acquired
  If (IDispatch(FAPI) = Nil) Or FTokenError Then
  Begin
    If FTokenError Then
      Writeln(CouldNotInitRemoteAPI)
    Else
      Writeln(CouldNotInitAPI);

    APIDone;

    Halt(R_ERROR_API_INITIALIZATION);
  End;
End;

Procedure APIDone;
Begin
  If IDispatch(FAPI) <> Nil Then FAPI.Done;
  Unset(TXObject(FAPI));
End;

Procedure CreateRPC(RPC: AnsiString);
Var
  URL: AnsiString;
Begin
  // No RPC given
  If Length(RPC) = $00 Then
  Begin
    // Get connection info
    Write('Enter the connection information (admin,pass,server): ');
    Readln(RPC);
  End;

  // Get file contents
  If Length(RPC) > $00 Then If Pos(cComma, RPC) = $00 Then RPC := LoadFileToString(RPC);

  // No proto
  If Pos(cProto, RPC) = $00 Then
  Begin
    // URL
    URL := URLEncode(GetCommaString(RPC, $00)) + cColon + URLEncode(GetCommaString(RPC, $01)) + cAt + GetCommaString(RPC, $02);

    // SSL support
    If GetCommaString(RPC, $03) <> '' Then URL := 'https://' + URL;
  End

  // URL
  Else
    URL := RPC;

  Try
    // Create token object
    FToken := Unassigned;
    FToken := TXTokenObject(TXVariant(CreateObject('IceWarpServer.TokenObject')));

    // Set URL
    FToken.URL := URL;

    // Get token handle
    TokenHandle := FToken.TokenHandle;
  Except
  End;
End;

Function GetCommaString(S: AnsiString; Index: Longint): AnsiString;
Var
  FC, FL, FI: Longint;
Begin
  Result := '';
  FL := $01;
  FC := $00;
  S := S + cComma;

  // For every char
  For FI := $01 To Length(S) Do
    // If comma
    If S[FI] = cComma Then
    Begin
      // Do we have our index
      If Index = FC Then
      Begin
        Result := Copy(S, FL, FI - FL);
        Break;
      End;

      // Inc counters
      Inc(FC);
      FL := FI + $01;
    End;
End;

Function FindParam(Var Index: Longint; const Param: AnsiString; Var Value: AnsiString): Boolean;
Var
  FIndex: Longint;
  FParam, FValue: AnsiString;
Begin
  Result := False;
  FIndex := Index;

  // For each param
  While GetNextParam(Index, FParam, FValue) Do
    // Match
    If LowerCase(FParam) = LowerCase(Param) Then
    Try
      // True
      Result := True;

      // Get value
      Value := FValue;
      
      Break;
    Except
    End;

  Index := FIndex;
End;

Function GetNextParam(Var Index: Longint; Var FParam, FValue: AnsiString; NoValue: Boolean = False): Boolean;
Var
  FL: Longint;
Begin
  Result := False;

  FParam := ParamStr(ParamOptions + Index);
  Inc(Index);

  If Not NoValue Then
  Begin
    FL := Pos(cEqual, FParam);
    If FL = $00 Then
    Begin
      FValue := ParamStr(ParamOptions + Index);
      Inc(Index);
    End
    Else
    Begin
      FValue := Copy(FParam, FL + $01, Length(FParam) - FL);
      FParam := Copy(FParam, $01, FL - $01);
    End;
  End;

  If Length(FParam) > $00 Then Result := True;
End;

Function GetProcessMode(Command: AnsiString): TProcessItem;
Begin
  Result := piDisplay;
  If (Command = CMODIFY) Or (Command = CSET) Then Result := piModify Else
  If (Command = CDISPLAY) Or (Command = CLIST) Or (Command = CGET) Then Result := piDisplay Else
  If (Command = CCHECK) Or (Command = CVALIDATE) Then Result := piValidate Else
  If (Command = CDELETE) Then Result := piDelete Else
  If (Command = CCREATE) Or (Command = CNEW) Or (Command = CADD) Then Result := piCreate Else
  If (Command = CSEARCH) Then Result := piSearch Else
  If (Command = CLOG) Then Result := piLog Else
  If (Command = CIMPORT) Then Result := piImport Else
  If (Command = CUPGRADE) Then Result := piUpgrade Else
  If (Command = CFILE) Then Result := piFile Else
  If (Command = CEXPORT) Then Result := piExport;
End;

Function CommaString(Str: AnsiString): AnsiString;
Begin
  Result := Str;

  // Check quot
  If Pos(cSpeech, Result) <> $00 Then Result := StringReplaceEx(Result, cSpeech, cBackSlash + cSpeech, [rfReplaceAll]);

  // Escape commas
  If Pos(cComma, Result) <> $00 Then Result := cSpeech + Result + cSpeech;
End;

Function ParamStr(Index: Longint): AnsiString;
Begin
  Result := '';
  If Index < Length(Parameters) Then Result := Parameters[Index];
End;

Function ParamCount: Longint;
Var
  FL: Longint;
Begin
  Result := $00;

  FL := Length(Parameters);
  If FL > $01 Then Result := FL - $01;
End;

Procedure ParseParameters;
Var
  FI: Longint;
Begin
  SetLength(Parameters, System.ParamCount + $01);
  For FI := $01 To Length(Parameters) Do Parameters[FI - $01] := AnsiString(System.ParamStr(FI - $01));
End;

Function ParseBatchLine(Line: AnsiString): Boolean;

var
  P: PAnsiChar;
  FS, S: AnsiString;
  FI, FL: Longint;
begin
  Result := False;

  If Length(Line) = $00 Then Exit;

  // We have an equal character
  FI := Pos(cEqual, Line);
  If FI <> $00 Then
  Begin
    FL := Pos(AnsiString('"'), Line);

    // Value with the equal sign
    If (FL = $00) Or (FI < FL) Then
    Begin
      // Blank value
      If Length(Line) = FI Then Exit;

      // Replace value
      Line[FI] := ' ';
      Insert('"', Line, FI + $01);
      Line := Line + '"';

      // Parameter
      FS := Copy(Line, $01, FI);
      FS := StringReplaceEx(FS, AnsiString('.'), AnsiString('_'), [rfReplaceAll]);
      Delete(Line, $01, FI);
      Line := FS + Line;
    End;
  End;

  // Command name
  SetLength(Parameters, $01);
  Parameters[$00] := AnsiString(System.ParamStr($00));
  ParamOptions := $00;

  // Reset
  P := PAnsiChar(Line);
  FI := $00;

  // Loop
  While True Do
  Begin
    // Get next string
    P := GetParamPChar(P, S);
    If Length(S) = $00 Then Break;

    // Count
    Inc(FI);

    // Add new item
    SetLength(Parameters, FI + $01);
    Parameters[FI] := S;
    Result := True;
  End;
End;

Procedure Writeln(Str: AnsiString = ''; Force: Boolean = False);
Begin
  If Not QuietMode Or Force Then System.Writeln(Str);
End;

Function IsStringMask(const S: AnsiString): Boolean;
Begin
  Result := (Pos(cAsterisk, S) <> $00) Or (Pos(cAsk, S) <> $00);
End;

End.
